/********************************************************************************
** Form generated from reading UI file 'rubycodegenerationformbase.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_RUBYCODEGENERATIONFORMBASE_H
#define UI_RUBYCODEGENERATIONFORMBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_RubyCodeGenerationFormBase
{
public:
    QGridLayout *gridLayout;
    QGridLayout *gridLayout1;
    QLabel *ui_textLabelTitle;
    QGroupBox *ui_groupBoxDocumentation;
    QHBoxLayout *hboxLayout;
    QLabel *ui_textLabelStyle;
    KComboBox *m_SelectCommentStyle;
    QGroupBox *ui_groupBoxAutoGeneratedMethods;
    QVBoxLayout *vboxLayout;
    QGridLayout *gridLayout2;
    QCheckBox *m_generateConstructors;
    QCheckBox *m_generateAssocAccessors;
    QCheckBox *m_generateAttribAccessors;
    QGridLayout *gridLayout3;
    QLabel *ui_textLabelAccessorScope;
    KComboBox *m_accessorScopeCB;
    QGridLayout *gridLayout4;
    QLabel *ui_textLabelAssocFieldScope;
    KComboBox *m_assocFieldScopeCB;

    void setupUi(QWidget *RubyCodeGenerationFormBase)
    {
        if (RubyCodeGenerationFormBase->objectName().isEmpty())
            RubyCodeGenerationFormBase->setObjectName("RubyCodeGenerationFormBase");
        RubyCodeGenerationFormBase->resize(462, 376);
        gridLayout = new QGridLayout(RubyCodeGenerationFormBase);
        gridLayout->setObjectName("gridLayout");
        gridLayout1 = new QGridLayout();
        gridLayout1->setObjectName("gridLayout1");
        ui_textLabelTitle = new QLabel(RubyCodeGenerationFormBase);
        ui_textLabelTitle->setObjectName("ui_textLabelTitle");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ui_textLabelTitle->sizePolicy().hasHeightForWidth());
        ui_textLabelTitle->setSizePolicy(sizePolicy);
        ui_textLabelTitle->setMaximumSize(QSize(16777215, 40));
        ui_textLabelTitle->setWordWrap(false);

        gridLayout1->addWidget(ui_textLabelTitle, 0, 0, 1, 1);

        ui_groupBoxDocumentation = new QGroupBox(RubyCodeGenerationFormBase);
        ui_groupBoxDocumentation->setObjectName("ui_groupBoxDocumentation");
        sizePolicy.setHeightForWidth(ui_groupBoxDocumentation->sizePolicy().hasHeightForWidth());
        ui_groupBoxDocumentation->setSizePolicy(sizePolicy);
        ui_groupBoxDocumentation->setMaximumSize(QSize(16777215, 100));
        hboxLayout = new QHBoxLayout(ui_groupBoxDocumentation);
        hboxLayout->setObjectName("hboxLayout");
        ui_textLabelStyle = new QLabel(ui_groupBoxDocumentation);
        ui_textLabelStyle->setObjectName("ui_textLabelStyle");
        ui_textLabelStyle->setWordWrap(false);

        hboxLayout->addWidget(ui_textLabelStyle);

        m_SelectCommentStyle = new KComboBox(ui_groupBoxDocumentation);
        m_SelectCommentStyle->addItem(QString());
        m_SelectCommentStyle->addItem(QString());
        m_SelectCommentStyle->setObjectName("m_SelectCommentStyle");

        hboxLayout->addWidget(m_SelectCommentStyle);


        gridLayout1->addWidget(ui_groupBoxDocumentation, 1, 0, 1, 1);

        ui_groupBoxAutoGeneratedMethods = new QGroupBox(RubyCodeGenerationFormBase);
        ui_groupBoxAutoGeneratedMethods->setObjectName("ui_groupBoxAutoGeneratedMethods");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(ui_groupBoxAutoGeneratedMethods->sizePolicy().hasHeightForWidth());
        ui_groupBoxAutoGeneratedMethods->setSizePolicy(sizePolicy1);
        vboxLayout = new QVBoxLayout(ui_groupBoxAutoGeneratedMethods);
        vboxLayout->setObjectName("vboxLayout");
        gridLayout2 = new QGridLayout();
        gridLayout2->setObjectName("gridLayout2");
        m_generateConstructors = new QCheckBox(ui_groupBoxAutoGeneratedMethods);
        m_generateConstructors->setObjectName("m_generateConstructors");
        m_generateConstructors->setChecked(false);

        gridLayout2->addWidget(m_generateConstructors, 0, 0, 1, 1);

        m_generateAssocAccessors = new QCheckBox(ui_groupBoxAutoGeneratedMethods);
        m_generateAssocAccessors->setObjectName("m_generateAssocAccessors");
        m_generateAssocAccessors->setChecked(true);

        gridLayout2->addWidget(m_generateAssocAccessors, 2, 0, 1, 1);

        m_generateAttribAccessors = new QCheckBox(ui_groupBoxAutoGeneratedMethods);
        m_generateAttribAccessors->setObjectName("m_generateAttribAccessors");
        m_generateAttribAccessors->setChecked(true);

        gridLayout2->addWidget(m_generateAttribAccessors, 1, 0, 1, 1);


        vboxLayout->addLayout(gridLayout2);

        gridLayout3 = new QGridLayout();
        gridLayout3->setObjectName("gridLayout3");
        ui_textLabelAccessorScope = new QLabel(ui_groupBoxAutoGeneratedMethods);
        ui_textLabelAccessorScope->setObjectName("ui_textLabelAccessorScope");
        ui_textLabelAccessorScope->setWordWrap(false);

        gridLayout3->addWidget(ui_textLabelAccessorScope, 0, 0, 1, 1);

        m_accessorScopeCB = new KComboBox(ui_groupBoxAutoGeneratedMethods);
        m_accessorScopeCB->addItem(QString());
        m_accessorScopeCB->addItem(QString());
        m_accessorScopeCB->addItem(QString());
        m_accessorScopeCB->addItem(QString());
        m_accessorScopeCB->setObjectName("m_accessorScopeCB");

        gridLayout3->addWidget(m_accessorScopeCB, 0, 1, 1, 1);


        vboxLayout->addLayout(gridLayout3);

        gridLayout4 = new QGridLayout();
        gridLayout4->setObjectName("gridLayout4");
        ui_textLabelAssocFieldScope = new QLabel(ui_groupBoxAutoGeneratedMethods);
        ui_textLabelAssocFieldScope->setObjectName("ui_textLabelAssocFieldScope");
        ui_textLabelAssocFieldScope->setWordWrap(false);

        gridLayout4->addWidget(ui_textLabelAssocFieldScope, 0, 0, 1, 1);

        m_assocFieldScopeCB = new KComboBox(ui_groupBoxAutoGeneratedMethods);
        m_assocFieldScopeCB->addItem(QString());
        m_assocFieldScopeCB->addItem(QString());
        m_assocFieldScopeCB->addItem(QString());
        m_assocFieldScopeCB->addItem(QString());
        m_assocFieldScopeCB->setObjectName("m_assocFieldScopeCB");

        gridLayout4->addWidget(m_assocFieldScopeCB, 0, 1, 1, 1);


        vboxLayout->addLayout(gridLayout4);


        gridLayout1->addWidget(ui_groupBoxAutoGeneratedMethods, 2, 0, 1, 1);


        gridLayout->addLayout(gridLayout1, 0, 0, 1, 1);


        retranslateUi(RubyCodeGenerationFormBase);

        m_accessorScopeCB->setCurrentIndex(3);
        m_assocFieldScopeCB->setCurrentIndex(3);


        QMetaObject::connectSlotsByName(RubyCodeGenerationFormBase);
    } // setupUi

    void retranslateUi(QWidget *RubyCodeGenerationFormBase)
    {
        ui_textLabelTitle->setText(tr2i18n("<p align=\"center\">Ruby Code Generation</p>", nullptr));
        ui_groupBoxDocumentation->setTitle(tr2i18n("Documentation", nullptr));
        ui_textLabelStyle->setText(tr2i18n("Style:", nullptr));
        m_SelectCommentStyle->setItemText(0, tr2i18n("Hash (#)", nullptr));
        m_SelectCommentStyle->setItemText(1, tr2i18n("Begin-End (=begin  =end)", nullptr));

        ui_groupBoxAutoGeneratedMethods->setTitle(tr2i18n("Auto-Generated Methods", nullptr));
        m_generateConstructors->setText(tr2i18n("Empty constructor methods", nullptr));
        m_generateAssocAccessors->setText(tr2i18n("Association accessor methods", nullptr));
        m_generateAttribAccessors->setText(tr2i18n("Attribute accessor methods", nullptr));
        ui_textLabelAccessorScope->setText(tr2i18n("Default attribute accessor scope:", nullptr));
        m_accessorScopeCB->setItemText(0, tr2i18n("Public", nullptr));
        m_accessorScopeCB->setItemText(1, tr2i18n("Private", nullptr));
        m_accessorScopeCB->setItemText(2, tr2i18n("Protected", nullptr));
        m_accessorScopeCB->setItemText(3, tr2i18n("From Parent Object", nullptr));

        ui_textLabelAssocFieldScope->setText(tr2i18n("Default association field scope:", nullptr));
        m_assocFieldScopeCB->setItemText(0, tr2i18n("Public", nullptr));
        m_assocFieldScopeCB->setItemText(1, tr2i18n("Private", nullptr));
        m_assocFieldScopeCB->setItemText(2, tr2i18n("Protected", nullptr));
        m_assocFieldScopeCB->setItemText(3, tr2i18n("From Parent Role", nullptr));

        (void)RubyCodeGenerationFormBase;
    } // retranslateUi

};

namespace Ui {
    class RubyCodeGenerationFormBase: public Ui_RubyCodeGenerationFormBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // RUBYCODEGENERATIONFORMBASE_H

