/****************************************************************************
** Meta object code from reading C++ file 'umllistview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../umbrello-26.07.80/umbrello/umllistview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'umllistview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11UMLListViewE_t {};
} // unnamed namespace

template <> constexpr inline auto UMLListView::qt_create_metaobjectdata<qt_meta_tag_ZN11UMLListViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UMLListView",
        "slotDiagramCreated",
        "",
        "Uml::ID::Type",
        "id",
        "slotDiagramRenamed",
        "slotDiagramRemoved",
        "slotObjectCreated",
        "UMLObject*",
        "object",
        "slotObjectRemoved",
        "connectNewObjectsSlots",
        "childObjectAdded",
        "UMLClassifierListItem*",
        "obj",
        "childObjectRemoved",
        "slotObjectChanged",
        "slotMenuSelection",
        "QAction*",
        "action",
        "QPoint",
        "position",
        "slotDropped",
        "QDropEvent*",
        "de",
        "UMLListViewItem*",
        "target",
        "expandAll",
        "item",
        "collapseAll",
        "slotCutSuccessful",
        "slotDeleteSelectedItems",
        "slotItemSelectionChanged",
        "slotExpanded",
        "QTreeWidgetItem*",
        "slotCollapsed"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotDiagramCreated'
        QtMocHelpers::SlotData<void(Uml::ID::Type)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'slotDiagramRenamed'
        QtMocHelpers::SlotData<void(Uml::ID::Type)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'slotDiagramRemoved'
        QtMocHelpers::SlotData<void(Uml::ID::Type)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'slotObjectCreated'
        QtMocHelpers::SlotData<void(UMLObject *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'slotObjectRemoved'
        QtMocHelpers::SlotData<void(UMLObject *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'connectNewObjectsSlots'
        QtMocHelpers::SlotData<void(UMLObject *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'childObjectAdded'
        QtMocHelpers::SlotData<void(UMLClassifierListItem *)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'childObjectRemoved'
        QtMocHelpers::SlotData<void(UMLClassifierListItem *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'slotObjectChanged'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotMenuSelection'
        QtMocHelpers::SlotData<void(QAction *, const QPoint &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { 0x80000000 | 20, 21 },
        }}),
        // Slot 'slotMenuSelection'
        QtMocHelpers::SlotData<void(QAction *)>(17, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'slotDropped'
        QtMocHelpers::SlotData<void(QDropEvent *, UMLListViewItem *)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 }, { 0x80000000 | 25, 26 },
        }}),
        // Slot 'expandAll'
        QtMocHelpers::SlotData<void(UMLListViewItem *)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 28 },
        }}),
        // Slot 'collapseAll'
        QtMocHelpers::SlotData<void(UMLListViewItem *)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 28 },
        }}),
        // Slot 'slotCutSuccessful'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDeleteSelectedItems'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotItemSelectionChanged'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotExpanded'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *)>(33, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 34, 28 },
        }}),
        // Slot 'slotCollapsed'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *)>(35, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 34, 28 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UMLListView, qt_meta_tag_ZN11UMLListViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UMLListView::staticMetaObject = { {
    QMetaObject::SuperData::link<QTreeWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11UMLListViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11UMLListViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11UMLListViewE_t>.metaTypes,
    nullptr
} };

void UMLListView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UMLListView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotDiagramCreated((*reinterpret_cast<std::add_pointer_t<Uml::ID::Type>>(_a[1]))); break;
        case 1: _t->slotDiagramRenamed((*reinterpret_cast<std::add_pointer_t<Uml::ID::Type>>(_a[1]))); break;
        case 2: _t->slotDiagramRemoved((*reinterpret_cast<std::add_pointer_t<Uml::ID::Type>>(_a[1]))); break;
        case 3: _t->slotObjectCreated((*reinterpret_cast<std::add_pointer_t<UMLObject*>>(_a[1]))); break;
        case 4: _t->slotObjectRemoved((*reinterpret_cast<std::add_pointer_t<UMLObject*>>(_a[1]))); break;
        case 5: _t->connectNewObjectsSlots((*reinterpret_cast<std::add_pointer_t<UMLObject*>>(_a[1]))); break;
        case 6: _t->childObjectAdded((*reinterpret_cast<std::add_pointer_t<UMLClassifierListItem*>>(_a[1]))); break;
        case 7: _t->childObjectRemoved((*reinterpret_cast<std::add_pointer_t<UMLClassifierListItem*>>(_a[1]))); break;
        case 8: _t->slotObjectChanged(); break;
        case 9: _t->slotMenuSelection((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 10: _t->slotMenuSelection((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 11: _t->slotDropped((*reinterpret_cast<std::add_pointer_t<QDropEvent*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<UMLListViewItem*>>(_a[2]))); break;
        case 12: _t->expandAll((*reinterpret_cast<std::add_pointer_t<UMLListViewItem*>>(_a[1]))); break;
        case 13: _t->collapseAll((*reinterpret_cast<std::add_pointer_t<UMLListViewItem*>>(_a[1]))); break;
        case 14: _t->slotCutSuccessful(); break;
        case 15: _t->slotDeleteSelectedItems(); break;
        case 16: _t->slotItemSelectionChanged(); break;
        case 17: _t->slotExpanded((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1]))); break;
        case 18: _t->slotCollapsed((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< UMLObject* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< UMLObject* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< UMLObject* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *UMLListView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UMLListView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11UMLListViewE_t>.strings))
        return static_cast<void*>(this);
    return QTreeWidget::qt_metacast(_clname);
}

int UMLListView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    return _id;
}
QT_WARNING_POP
