/****************************************************************************
** Meta object code from reading C++ file 'classifiercodedocument.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../umbrello-26.07.80/umbrello/codegenerators/classifiercodedocument.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'classifiercodedocument.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22ClassifierCodeDocumentE_t {};
} // unnamed namespace

template <> constexpr inline auto ClassifierCodeDocument::qt_create_metaobjectdata<qt_meta_tag_ZN22ClassifierCodeDocumentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ClassifierCodeDocument",
        "addAttributeClassField",
        "",
        "UMLClassifierListItem*",
        "at",
        "syncToParentIfAdded",
        "addAssociationClassField",
        "UMLAssociation*",
        "assoc",
        "removeAttributeClassField",
        "removeAssociationClassField",
        "addOperation",
        "obj",
        "removeOperation",
        "syncToParent"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'addAttributeClassField'
        QtMocHelpers::SlotData<void(UMLClassifierListItem *, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 5 },
        }}),
        // Slot 'addAttributeClassField'
        QtMocHelpers::SlotData<void(UMLClassifierListItem *)>(1, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'addAssociationClassField'
        QtMocHelpers::SlotData<void(UMLAssociation *, bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::Bool, 5 },
        }}),
        // Slot 'addAssociationClassField'
        QtMocHelpers::SlotData<void(UMLAssociation *)>(6, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'removeAttributeClassField'
        QtMocHelpers::SlotData<void(UMLClassifierListItem *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'removeAssociationClassField'
        QtMocHelpers::SlotData<void(UMLAssociation *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'addOperation'
        QtMocHelpers::SlotData<void(UMLClassifierListItem *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 12 },
        }}),
        // Slot 'removeOperation'
        QtMocHelpers::SlotData<void(UMLClassifierListItem *)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 12 },
        }}),
        // Slot 'syncToParent'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ClassifierCodeDocument, qt_meta_tag_ZN22ClassifierCodeDocumentE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ClassifierCodeDocument::staticMetaObject = { {
    QMetaObject::SuperData::link<CodeDocument::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22ClassifierCodeDocumentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22ClassifierCodeDocumentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22ClassifierCodeDocumentE_t>.metaTypes,
    nullptr
} };

void ClassifierCodeDocument::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ClassifierCodeDocument *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->addAttributeClassField((*reinterpret_cast<std::add_pointer_t<UMLClassifierListItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 1: _t->addAttributeClassField((*reinterpret_cast<std::add_pointer_t<UMLClassifierListItem*>>(_a[1]))); break;
        case 2: _t->addAssociationClassField((*reinterpret_cast<std::add_pointer_t<UMLAssociation*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 3: _t->addAssociationClassField((*reinterpret_cast<std::add_pointer_t<UMLAssociation*>>(_a[1]))); break;
        case 4: _t->removeAttributeClassField((*reinterpret_cast<std::add_pointer_t<UMLClassifierListItem*>>(_a[1]))); break;
        case 5: _t->removeAssociationClassField((*reinterpret_cast<std::add_pointer_t<UMLAssociation*>>(_a[1]))); break;
        case 6: _t->addOperation((*reinterpret_cast<std::add_pointer_t<UMLClassifierListItem*>>(_a[1]))); break;
        case 7: _t->removeOperation((*reinterpret_cast<std::add_pointer_t<UMLClassifierListItem*>>(_a[1]))); break;
        case 8: _t->syncToParent(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< UMLClassifierListItem* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< UMLClassifierListItem* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< UMLClassifierListItem* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< UMLClassifierListItem* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< UMLClassifierListItem* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *ClassifierCodeDocument::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ClassifierCodeDocument::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22ClassifierCodeDocumentE_t>.strings))
        return static_cast<void*>(this);
    return CodeDocument::qt_metacast(_clname);
}

int ClassifierCodeDocument::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = CodeDocument::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}
QT_WARNING_POP
