/********************************************************************************
** Form generated from reading UI file 'cppcodegenerationformbase.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CPPCODEGENERATIONFORMBASE_H
#define UI_CPPCODEGENERATIONFORMBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KHistoryComboBox"

QT_BEGIN_NAMESPACE

class Ui_CPPCodeGenerationFormBase
{
public:
    QVBoxLayout *vboxLayout;
    QGridLayout *ui_gridLayoutMain;
    QLabel *ui_textLabelTitle;
    QTabWidget *ui_tabWidget;
    QWidget *ui_tabGeneral;
    QWidget *layoutWidget;
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label;
    QLineEdit *ui_classMemberPrefixEdit;
    QListWidget *ui_generalOptionsListWidget;
    QWidget *ui_tabMethodBodyGeneration;
    QGridLayout *gridLayout1;
    QSpacerItem *spacerItem;
    QGridLayout *ui_includeFilesList;
    KHistoryComboBox *ui_listClassHCombo;
    QLabel *ui_textLabelVariable;
    QPushButton *ui_browseStringButton;
    QCheckBox *ui_globalStringCheckBox;
    KHistoryComboBox *ui_stringClassHCombo;
    QSpacerItem *spacerItem1;
    QSpacerItem *spacerItem2;
    QLabel *ui_textLabelStringClass;
    QLabel *ui_textLabelListClass;
    QCheckBox *ui_globalListCheckBox;
    QPushButton *ui_browseListButton;
    QLabel *ui_textLabelGlobal;
    KHistoryComboBox *ui_listIncludeFileHistoryCombo;
    KHistoryComboBox *ui_stringIncludeFileHistoryCombo;
    QLabel *ui_textLabelClassName;
    QLabel *ui_textLabelIncludeFile;
    QLabel *ui_textLabelHelpMethodBodyGen;
    QGroupBox *ui_groupBoxDocumentation;
    QHBoxLayout *horizontalLayout;
    QLabel *ui_textLabelStyle;
    QComboBox *ui_selectCommentStyle;

    void setupUi(QWidget *CPPCodeGenerationFormBase)
    {
        if (CPPCodeGenerationFormBase->objectName().isEmpty())
            CPPCodeGenerationFormBase->setObjectName("CPPCodeGenerationFormBase");
        CPPCodeGenerationFormBase->resize(463, 488);
        vboxLayout = new QVBoxLayout(CPPCodeGenerationFormBase);
        vboxLayout->setObjectName("vboxLayout");
        ui_gridLayoutMain = new QGridLayout();
        ui_gridLayoutMain->setObjectName("ui_gridLayoutMain");
        ui_textLabelTitle = new QLabel(CPPCodeGenerationFormBase);
        ui_textLabelTitle->setObjectName("ui_textLabelTitle");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ui_textLabelTitle->sizePolicy().hasHeightForWidth());
        ui_textLabelTitle->setSizePolicy(sizePolicy);
        ui_textLabelTitle->setMaximumSize(QSize(16777215, 40));
        ui_textLabelTitle->setWordWrap(false);

        ui_gridLayoutMain->addWidget(ui_textLabelTitle, 0, 0, 1, 1);

        ui_tabWidget = new QTabWidget(CPPCodeGenerationFormBase);
        ui_tabWidget->setObjectName("ui_tabWidget");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(ui_tabWidget->sizePolicy().hasHeightForWidth());
        ui_tabWidget->setSizePolicy(sizePolicy1);
        ui_tabGeneral = new QWidget();
        ui_tabGeneral->setObjectName("ui_tabGeneral");
        layoutWidget = new QWidget(ui_tabGeneral);
        layoutWidget->setObjectName("layoutWidget");
        layoutWidget->setGeometry(QRect(4, 4, 441, 222));
        gridLayout = new QGridLayout(layoutWidget);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label = new QLabel(layoutWidget);
        label->setObjectName("label");

        horizontalLayout_2->addWidget(label);

        ui_classMemberPrefixEdit = new QLineEdit(layoutWidget);
        ui_classMemberPrefixEdit->setObjectName("ui_classMemberPrefixEdit");

        horizontalLayout_2->addWidget(ui_classMemberPrefixEdit);


        gridLayout->addLayout(horizontalLayout_2, 0, 0, 1, 1);

        ui_generalOptionsListWidget = new QListWidget(layoutWidget);
        ui_generalOptionsListWidget->setObjectName("ui_generalOptionsListWidget");

        gridLayout->addWidget(ui_generalOptionsListWidget, 1, 0, 1, 1);

        ui_tabWidget->addTab(ui_tabGeneral, QString());
        ui_tabMethodBodyGeneration = new QWidget();
        ui_tabMethodBodyGeneration->setObjectName("ui_tabMethodBodyGeneration");
        gridLayout1 = new QGridLayout(ui_tabMethodBodyGeneration);
        gridLayout1->setObjectName("gridLayout1");
        spacerItem = new QSpacerItem(410, 113, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout1->addItem(spacerItem, 2, 0, 1, 1);

        ui_includeFilesList = new QGridLayout();
        ui_includeFilesList->setObjectName("ui_includeFilesList");
        ui_listClassHCombo = new KHistoryComboBox(ui_tabMethodBodyGeneration);
        ui_listClassHCombo->setObjectName("ui_listClassHCombo");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(ui_listClassHCombo->sizePolicy().hasHeightForWidth());
        ui_listClassHCombo->setSizePolicy(sizePolicy2);
        ui_listClassHCombo->setEditable(false);
        ui_listClassHCombo->setDuplicatesEnabled(false);
        ui_listClassHCombo->setProperty("currentItem", QVariant(0));

        ui_includeFilesList->addWidget(ui_listClassHCombo, 1, 1, 1, 1);

        ui_textLabelVariable = new QLabel(ui_tabMethodBodyGeneration);
        ui_textLabelVariable->setObjectName("ui_textLabelVariable");
        ui_textLabelVariable->setWordWrap(false);

        ui_includeFilesList->addWidget(ui_textLabelVariable, 0, 0, 1, 1);

        ui_browseStringButton = new QPushButton(ui_tabMethodBodyGeneration);
        ui_browseStringButton->setObjectName("ui_browseStringButton");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(ui_browseStringButton->sizePolicy().hasHeightForWidth());
        ui_browseStringButton->setSizePolicy(sizePolicy3);
        ui_browseStringButton->setMaximumSize(QSize(32, 32767));

        ui_includeFilesList->addWidget(ui_browseStringButton, 2, 4, 1, 1);

        ui_globalStringCheckBox = new QCheckBox(ui_tabMethodBodyGeneration);
        ui_globalStringCheckBox->setObjectName("ui_globalStringCheckBox");
        ui_globalStringCheckBox->setChecked(true);

        ui_includeFilesList->addWidget(ui_globalStringCheckBox, 2, 7, 1, 1);

        ui_stringClassHCombo = new KHistoryComboBox(ui_tabMethodBodyGeneration);
        ui_stringClassHCombo->setObjectName("ui_stringClassHCombo");
        sizePolicy2.setHeightForWidth(ui_stringClassHCombo->sizePolicy().hasHeightForWidth());
        ui_stringClassHCombo->setSizePolicy(sizePolicy2);
        ui_stringClassHCombo->setEditable(false);
        ui_stringClassHCombo->setDuplicatesEnabled(false);
        ui_stringClassHCombo->setProperty("currentItem", QVariant(0));

        ui_includeFilesList->addWidget(ui_stringClassHCombo, 2, 1, 1, 1);

        spacerItem1 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        ui_includeFilesList->addItem(spacerItem1, 2, 6, 1, 1);

        spacerItem2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        ui_includeFilesList->addItem(spacerItem2, 1, 6, 1, 1);

        ui_textLabelStringClass = new QLabel(ui_tabMethodBodyGeneration);
        ui_textLabelStringClass->setObjectName("ui_textLabelStringClass");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(ui_textLabelStringClass->sizePolicy().hasHeightForWidth());
        ui_textLabelStringClass->setSizePolicy(sizePolicy4);
        ui_textLabelStringClass->setWordWrap(false);

        ui_includeFilesList->addWidget(ui_textLabelStringClass, 2, 0, 1, 1);

        ui_textLabelListClass = new QLabel(ui_tabMethodBodyGeneration);
        ui_textLabelListClass->setObjectName("ui_textLabelListClass");
        sizePolicy4.setHeightForWidth(ui_textLabelListClass->sizePolicy().hasHeightForWidth());
        ui_textLabelListClass->setSizePolicy(sizePolicy4);
        ui_textLabelListClass->setWordWrap(false);

        ui_includeFilesList->addWidget(ui_textLabelListClass, 1, 0, 1, 1);

        ui_globalListCheckBox = new QCheckBox(ui_tabMethodBodyGeneration);
        ui_globalListCheckBox->setObjectName("ui_globalListCheckBox");
        ui_globalListCheckBox->setChecked(true);

        ui_includeFilesList->addWidget(ui_globalListCheckBox, 1, 7, 1, 1);

        ui_browseListButton = new QPushButton(ui_tabMethodBodyGeneration);
        ui_browseListButton->setObjectName("ui_browseListButton");
        sizePolicy2.setHeightForWidth(ui_browseListButton->sizePolicy().hasHeightForWidth());
        ui_browseListButton->setSizePolicy(sizePolicy2);
        ui_browseListButton->setMaximumSize(QSize(32, 32767));

        ui_includeFilesList->addWidget(ui_browseListButton, 1, 4, 1, 1);

        ui_textLabelGlobal = new QLabel(ui_tabMethodBodyGeneration);
        ui_textLabelGlobal->setObjectName("ui_textLabelGlobal");
        ui_textLabelGlobal->setWordWrap(false);

        ui_includeFilesList->addWidget(ui_textLabelGlobal, 0, 7, 1, 1);

        ui_listIncludeFileHistoryCombo = new KHistoryComboBox(ui_tabMethodBodyGeneration);
        ui_listIncludeFileHistoryCombo->setObjectName("ui_listIncludeFileHistoryCombo");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(ui_listIncludeFileHistoryCombo->sizePolicy().hasHeightForWidth());
        ui_listIncludeFileHistoryCombo->setSizePolicy(sizePolicy5);
        ui_listIncludeFileHistoryCombo->setProperty("currentItem", QVariant(0));

        ui_includeFilesList->addWidget(ui_listIncludeFileHistoryCombo, 1, 2, 1, 1);

        ui_stringIncludeFileHistoryCombo = new KHistoryComboBox(ui_tabMethodBodyGeneration);
        ui_stringIncludeFileHistoryCombo->setObjectName("ui_stringIncludeFileHistoryCombo");
        sizePolicy5.setHeightForWidth(ui_stringIncludeFileHistoryCombo->sizePolicy().hasHeightForWidth());
        ui_stringIncludeFileHistoryCombo->setSizePolicy(sizePolicy5);
        ui_stringIncludeFileHistoryCombo->setProperty("currentItem", QVariant(0));

        ui_includeFilesList->addWidget(ui_stringIncludeFileHistoryCombo, 2, 2, 1, 1);

        ui_textLabelClassName = new QLabel(ui_tabMethodBodyGeneration);
        ui_textLabelClassName->setObjectName("ui_textLabelClassName");
        ui_textLabelClassName->setWordWrap(false);

        ui_includeFilesList->addWidget(ui_textLabelClassName, 0, 1, 1, 1);

        ui_textLabelIncludeFile = new QLabel(ui_tabMethodBodyGeneration);
        ui_textLabelIncludeFile->setObjectName("ui_textLabelIncludeFile");
        ui_textLabelIncludeFile->setWordWrap(false);

        ui_includeFilesList->addWidget(ui_textLabelIncludeFile, 0, 2, 1, 1);


        gridLayout1->addLayout(ui_includeFilesList, 1, 0, 1, 1);

        ui_textLabelHelpMethodBodyGen = new QLabel(ui_tabMethodBodyGeneration);
        ui_textLabelHelpMethodBodyGen->setObjectName("ui_textLabelHelpMethodBodyGen");
        ui_textLabelHelpMethodBodyGen->setWordWrap(false);

        gridLayout1->addWidget(ui_textLabelHelpMethodBodyGen, 0, 0, 1, 1);

        ui_tabWidget->addTab(ui_tabMethodBodyGeneration, QString());

        ui_gridLayoutMain->addWidget(ui_tabWidget, 2, 0, 1, 1);

        ui_groupBoxDocumentation = new QGroupBox(CPPCodeGenerationFormBase);
        ui_groupBoxDocumentation->setObjectName("ui_groupBoxDocumentation");
        QSizePolicy sizePolicy6(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(80);
        sizePolicy6.setHeightForWidth(ui_groupBoxDocumentation->sizePolicy().hasHeightForWidth());
        ui_groupBoxDocumentation->setSizePolicy(sizePolicy6);
        ui_groupBoxDocumentation->setMaximumSize(QSize(16777215, 100));
        horizontalLayout = new QHBoxLayout(ui_groupBoxDocumentation);
        horizontalLayout->setObjectName("horizontalLayout");
        ui_textLabelStyle = new QLabel(ui_groupBoxDocumentation);
        ui_textLabelStyle->setObjectName("ui_textLabelStyle");
        ui_textLabelStyle->setWordWrap(false);

        horizontalLayout->addWidget(ui_textLabelStyle);

        ui_selectCommentStyle = new QComboBox(ui_groupBoxDocumentation);
        ui_selectCommentStyle->addItem(QString());
        ui_selectCommentStyle->addItem(QString());
        ui_selectCommentStyle->setObjectName("ui_selectCommentStyle");

        horizontalLayout->addWidget(ui_selectCommentStyle);


        ui_gridLayoutMain->addWidget(ui_groupBoxDocumentation, 1, 0, 1, 1);


        vboxLayout->addLayout(ui_gridLayoutMain);


        retranslateUi(CPPCodeGenerationFormBase);

        ui_tabWidget->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(CPPCodeGenerationFormBase);
    } // setupUi

    void retranslateUi(QWidget *CPPCodeGenerationFormBase)
    {
        ui_textLabelTitle->setText(tr2i18n("<p align=\"center\">C++ Code Generation</p>", nullptr));
        label->setText(tr2i18n("Class member prefix", nullptr));
        ui_tabWidget->setTabText(ui_tabWidget->indexOf(ui_tabGeneral), tr2i18n("General", nullptr));
        ui_listClassHCombo->setHistoryItems(QStringList{
            tr2i18n("QPtrList", nullptr),
            tr2i18n("vector", nullptr),
            tr2i18n("vector", nullptr)});
        ui_textLabelVariable->setText(tr2i18n("<b>Variable</b>", nullptr));
        ui_browseStringButton->setText(tr2i18n("...", nullptr));
        ui_globalStringCheckBox->setText(QString());
        ui_stringClassHCombo->setHistoryItems(QStringList{
            tr2i18n("QString", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("QString", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("QString", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("QString", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("QString", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("QString", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("QString", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("QString", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("QString", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("QString", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("QString", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("QString", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("QString", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("QString", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("QString", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("QString", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("QString", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("QString", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("QString", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("QString", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("QString", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("QString", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("QString", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("QString", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("QString", nullptr),
            tr2i18n("string", nullptr)});
        ui_textLabelStringClass->setText(tr2i18n("<p align=\"center\">String</p>", nullptr));
        ui_textLabelListClass->setText(tr2i18n("<p align=\"center\">List</p>", nullptr));
        ui_globalListCheckBox->setText(QString());
        ui_browseListButton->setText(tr2i18n("...", nullptr));
        ui_textLabelGlobal->setText(tr2i18n("<i>global?</i>", nullptr));
        ui_listIncludeFileHistoryCombo->setHistoryItems(QStringList{
            tr2i18n("qptrlist.h", nullptr),
            tr2i18n("vector", nullptr),
            tr2i18n("qptrlist.h", nullptr),
            tr2i18n("vector", nullptr),
            tr2i18n("qptrlist.h", nullptr),
            tr2i18n("vector", nullptr),
            tr2i18n("qptrlist.h", nullptr),
            tr2i18n("vector", nullptr),
            tr2i18n("qptrlist.h", nullptr),
            tr2i18n("vector", nullptr),
            tr2i18n("qptrlist.h", nullptr),
            tr2i18n("vector", nullptr),
            tr2i18n("qptrlist.h", nullptr),
            tr2i18n("vector", nullptr),
            tr2i18n("qptrlist.h", nullptr),
            tr2i18n("vector", nullptr),
            tr2i18n("qptrlist.h", nullptr),
            tr2i18n("vector", nullptr),
            tr2i18n("qptrlist.h", nullptr),
            tr2i18n("vector", nullptr),
            tr2i18n("qptrlist.h", nullptr),
            tr2i18n("vector", nullptr),
            tr2i18n("qptrlist.h", nullptr),
            tr2i18n("vector", nullptr),
            tr2i18n("qptrlist.h", nullptr),
            tr2i18n("vector", nullptr),
            tr2i18n("qptrlist.h", nullptr),
            tr2i18n("vector", nullptr),
            tr2i18n("qptrlist.h", nullptr),
            tr2i18n("vector", nullptr),
            tr2i18n("qptrlist.h", nullptr),
            tr2i18n("vector", nullptr),
            tr2i18n("qptrlist.h", nullptr),
            tr2i18n("vector", nullptr),
            tr2i18n("qptrlist.h", nullptr),
            tr2i18n("vector", nullptr),
            tr2i18n("qptrlist.h", nullptr),
            tr2i18n("vector", nullptr),
            tr2i18n("qptrlist.h", nullptr),
            tr2i18n("vector", nullptr),
            tr2i18n("qptrlist.h", nullptr),
            tr2i18n("vector", nullptr),
            tr2i18n("qptrlist.h", nullptr),
            tr2i18n("vector", nullptr),
            tr2i18n("qptrlist.h", nullptr),
            tr2i18n("vector", nullptr),
            tr2i18n("qptrlist.h", nullptr),
            tr2i18n("vector", nullptr),
            tr2i18n("qptrlist.h", nullptr),
            tr2i18n("vector", nullptr)});
        ui_stringIncludeFileHistoryCombo->setHistoryItems(QStringList{
            tr2i18n("qstring.h", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("qstring.h", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("qstring.h", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("qstring.h", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("qstring.h", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("qstring.h", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("qstring.h", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("qstring.h", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("qstring.h", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("qstring.h", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("qstring.h", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("qstring.h", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("qstring.h", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("qstring.h", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("qstring.h", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("qstring.h", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("qstring.h", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("qstring.h", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("qstring.h", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("qstring.h", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("qstring.h", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("qstring.h", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("qstring.h", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("qstring.h", nullptr),
            tr2i18n("string", nullptr),
            tr2i18n("qstring.h", nullptr),
            tr2i18n("string", nullptr)});
        ui_textLabelClassName->setText(tr2i18n("Class name", nullptr));
        ui_textLabelIncludeFile->setText(tr2i18n("<i><p align=\"center\">Include file</p></i>", nullptr));
        ui_textLabelHelpMethodBodyGen->setText(tr2i18n("Use following for classes in generated code:", nullptr));
        ui_tabWidget->setTabText(ui_tabWidget->indexOf(ui_tabMethodBodyGeneration), tr2i18n("Method Body Generation", nullptr));
        ui_groupBoxDocumentation->setTitle(tr2i18n("Documentation", nullptr));
        ui_textLabelStyle->setText(tr2i18n("Style:", nullptr));
        ui_selectCommentStyle->setItemText(0, tr2i18n("Slash-Slash (//)", nullptr));
        ui_selectCommentStyle->setItemText(1, tr2i18n("Slash-Star (/**  */)", nullptr));

        (void)CPPCodeGenerationFormBase;
    } // retranslateUi

};

namespace Ui {
    class CPPCodeGenerationFormBase: public Ui_CPPCodeGenerationFormBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CPPCODEGENERATIONFORMBASE_H

