/****************************************************************************
** Meta object code from reading C++ file 'umlapp.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../umbrello-26.07.80/umbrello/umlapp.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'umlapp.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6UMLAppE_t {};
} // unnamed namespace

template <> constexpr inline auto UMLApp::qt_create_metaobjectdata<qt_meta_tag_ZN6UMLAppE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UMLApp",
        "sigCutSuccessful",
        "",
        "slotExecGenerationWizard",
        "slotImportingWizard",
        "slotFileNew",
        "slotFileOpen",
        "slotFileOpenRecent",
        "QUrl",
        "url",
        "slotFileSave",
        "slotFileSaveAs",
        "slotFileClose",
        "slotPrintSettings",
        "slotPrintPreview",
        "slotPrintPreviewPaintRequested",
        "QPrinter*",
        "printer",
        "slotFilePrint",
        "slotFileQuit",
        "slotFileExportDocbook",
        "slotFileExportXhtml",
        "slotFind",
        "slotFindNext",
        "slotFindPrevious",
        "slotEditCut",
        "slotEditCopy",
        "slotEditPaste",
        "slotStatusMsg",
        "text",
        "slotClassDiagram",
        "slotObjectDiagram",
        "slotSequenceDiagram",
        "slotCollaborationDiagram",
        "slotUseCaseDiagram",
        "slotStateDiagram",
        "slotActivityDiagram",
        "slotComponentDiagram",
        "slotDeploymentDiagram",
        "slotEntityRelationshipDiagram",
        "slotAlignLeft",
        "slotAlignRight",
        "slotAlignTop",
        "slotAlignBottom",
        "slotAlignVerticalMiddle",
        "slotAlignHorizontalMiddle",
        "slotAlignVerticalDistribute",
        "slotAlignHorizontalDistribute",
        "slotClipDataChanged",
        "slotCopyChanged",
        "slotPrefs",
        "MultiPageDialogBase::PageType",
        "page",
        "slotApplyPrefs",
        "slotImportClass",
        "slotImportProject",
        "slotUpdateViews",
        "slotCurrentViewClearDiagram",
        "slotCurrentViewToggleSnapToGrid",
        "slotCurrentViewToggleShowGrid",
        "slotCurrentViewExportImage",
        "slotViewsExportImages",
        "slotCurrentProperties",
        "slotClassWizard",
        "slotAddDefaultDatatypes",
        "slotCurrentViewChanged",
        "slotSnapToGridToggled",
        "gridOn",
        "slotShowGridToggled",
        "slotSelectAll",
        "slotDeleteSelected",
        "slotDeleteDiagram",
        "slotCloseDiagram",
        "index",
        "slotGenerateAllCode",
        "slotSetZoom",
        "QAction*",
        "action",
        "slotZoomSliderMoved",
        "value",
        "slotZoomFit",
        "slotZoom100",
        "slotZoomOut",
        "slotZoomIn",
        "slotBirdViewChanged",
        "QPointF",
        "newCenter",
        "setupZoomMenu",
        "slotEditUndo",
        "slotEditRedo",
        "slotTabChanged",
        "slotChangeTabLeft",
        "slotChangeTabRight",
        "slotMoveTabLeft",
        "slotMoveTabRight",
        "slotXhtmlDocGenerationFinished",
        "status",
        "slotOpenFileInEditor",
        "file",
        "startCursor",
        "endCursor",
        "setLang_actionscript",
        "setLang_ada",
        "setLang_cpp",
        "setLang_csharp",
        "setLang_d",
        "setLang_idl",
        "setLang_java",
        "setLang_javascript",
        "setLang_mysql",
        "setLang_pascal",
        "setLang_perl",
        "setLang_php",
        "setLang_php5",
        "setLang_postgresql",
        "setLang_python",
        "setLang_ruby",
        "setLang_sql",
        "setLang_tcl",
        "setLang_vala",
        "setLang_xmlschema",
        "setLang_none",
        "slotDiagramPopupMenu",
        "QPoint",
        "point"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigCutSuccessful'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotExecGenerationWizard'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotImportingWizard'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFileNew'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFileOpen'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFileOpenRecent'
        QtMocHelpers::SlotData<void(const QUrl &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'slotFileSave'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFileSaveAs'
        QtMocHelpers::SlotData<bool()>(11, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'slotFileClose'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPrintSettings'
        QtMocHelpers::SlotData<bool()>(13, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'slotPrintPreview'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPrintPreviewPaintRequested'
        QtMocHelpers::SlotData<void(QPrinter *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'slotFilePrint'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFileQuit'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFileExportDocbook'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFileExportXhtml'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFind'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFindNext'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFindPrevious'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotEditCut'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotEditCopy'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotEditPaste'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotStatusMsg'
        QtMocHelpers::SlotData<void(const QString &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 29 },
        }}),
        // Slot 'slotClassDiagram'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotObjectDiagram'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSequenceDiagram'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCollaborationDiagram'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotUseCaseDiagram'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotStateDiagram'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotActivityDiagram'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotComponentDiagram'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDeploymentDiagram'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotEntityRelationshipDiagram'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAlignLeft'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAlignRight'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAlignTop'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAlignBottom'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAlignVerticalMiddle'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAlignHorizontalMiddle'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAlignVerticalDistribute'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAlignHorizontalDistribute'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotClipDataChanged'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCopyChanged'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPrefs'
        QtMocHelpers::SlotData<void(MultiPageDialogBase::PageType)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 51, 52 },
        }}),
        // Slot 'slotPrefs'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotApplyPrefs'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotImportClass'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotImportProject'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotUpdateViews'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCurrentViewClearDiagram'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCurrentViewToggleSnapToGrid'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCurrentViewToggleShowGrid'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCurrentViewExportImage'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotViewsExportImages'
        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCurrentProperties'
        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotClassWizard'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAddDefaultDatatypes'
        QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCurrentViewChanged'
        QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSnapToGridToggled'
        QtMocHelpers::SlotData<void(bool)>(66, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 67 },
        }}),
        // Slot 'slotShowGridToggled'
        QtMocHelpers::SlotData<void(bool)>(68, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 67 },
        }}),
        // Slot 'slotSelectAll'
        QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDeleteSelected'
        QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDeleteDiagram'
        QtMocHelpers::SlotData<void()>(71, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCloseDiagram'
        QtMocHelpers::SlotData<void(int)>(72, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 73 },
        }}),
        // Slot 'slotGenerateAllCode'
        QtMocHelpers::SlotData<void()>(74, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSetZoom'
        QtMocHelpers::SlotData<void(QAction *)>(75, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 76, 77 },
        }}),
        // Slot 'slotZoomSliderMoved'
        QtMocHelpers::SlotData<void(int)>(78, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 79 },
        }}),
        // Slot 'slotZoomFit'
        QtMocHelpers::SlotData<void()>(80, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotZoom100'
        QtMocHelpers::SlotData<void()>(81, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotZoomOut'
        QtMocHelpers::SlotData<void()>(82, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotZoomIn'
        QtMocHelpers::SlotData<void()>(83, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotBirdViewChanged'
        QtMocHelpers::SlotData<void(const QPointF &)>(84, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 85, 86 },
        }}),
        // Slot 'setupZoomMenu'
        QtMocHelpers::SlotData<void()>(87, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotEditUndo'
        QtMocHelpers::SlotData<void()>(88, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotEditRedo'
        QtMocHelpers::SlotData<void()>(89, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotTabChanged'
        QtMocHelpers::SlotData<void(int)>(90, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 73 },
        }}),
        // Slot 'slotChangeTabLeft'
        QtMocHelpers::SlotData<void()>(91, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotChangeTabRight'
        QtMocHelpers::SlotData<void()>(92, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotMoveTabLeft'
        QtMocHelpers::SlotData<void()>(93, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotMoveTabRight'
        QtMocHelpers::SlotData<void()>(94, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotXhtmlDocGenerationFinished'
        QtMocHelpers::SlotData<void(bool)>(95, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 96 },
        }}),
        // Slot 'slotOpenFileInEditor'
        QtMocHelpers::SlotData<bool(const QUrl &, int, int)>(97, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 8, 98 }, { QMetaType::Int, 99 }, { QMetaType::Int, 100 },
        }}),
        // Slot 'slotOpenFileInEditor'
        QtMocHelpers::SlotData<bool(const QUrl &, int)>(97, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { 0x80000000 | 8, 98 }, { QMetaType::Int, 99 },
        }}),
        // Slot 'slotOpenFileInEditor'
        QtMocHelpers::SlotData<bool(const QUrl &)>(97, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { 0x80000000 | 8, 98 },
        }}),
        // Slot 'setLang_actionscript'
        QtMocHelpers::SlotData<void()>(101, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setLang_ada'
        QtMocHelpers::SlotData<void()>(102, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setLang_cpp'
        QtMocHelpers::SlotData<void()>(103, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setLang_csharp'
        QtMocHelpers::SlotData<void()>(104, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setLang_d'
        QtMocHelpers::SlotData<void()>(105, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setLang_idl'
        QtMocHelpers::SlotData<void()>(106, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setLang_java'
        QtMocHelpers::SlotData<void()>(107, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setLang_javascript'
        QtMocHelpers::SlotData<void()>(108, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setLang_mysql'
        QtMocHelpers::SlotData<void()>(109, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setLang_pascal'
        QtMocHelpers::SlotData<void()>(110, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setLang_perl'
        QtMocHelpers::SlotData<void()>(111, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setLang_php'
        QtMocHelpers::SlotData<void()>(112, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setLang_php5'
        QtMocHelpers::SlotData<void()>(113, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setLang_postgresql'
        QtMocHelpers::SlotData<void()>(114, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setLang_python'
        QtMocHelpers::SlotData<void()>(115, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setLang_ruby'
        QtMocHelpers::SlotData<void()>(116, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setLang_sql'
        QtMocHelpers::SlotData<void()>(117, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setLang_tcl'
        QtMocHelpers::SlotData<void()>(118, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setLang_vala'
        QtMocHelpers::SlotData<void()>(119, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setLang_xmlschema'
        QtMocHelpers::SlotData<void()>(120, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setLang_none'
        QtMocHelpers::SlotData<void()>(121, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDiagramPopupMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(122, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 123, 124 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UMLApp, qt_meta_tag_ZN6UMLAppE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UMLApp::staticMetaObject = { {
    QMetaObject::SuperData::link<KXmlGuiWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6UMLAppE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6UMLAppE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6UMLAppE_t>.metaTypes,
    nullptr
} };

void UMLApp::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UMLApp *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigCutSuccessful(); break;
        case 1: _t->slotExecGenerationWizard(); break;
        case 2: _t->slotImportingWizard(); break;
        case 3: _t->slotFileNew(); break;
        case 4: _t->slotFileOpen(); break;
        case 5: _t->slotFileOpenRecent((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 6: _t->slotFileSave(); break;
        case 7: { bool _r = _t->slotFileSaveAs();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->slotFileClose(); break;
        case 9: { bool _r = _t->slotPrintSettings();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->slotPrintPreview(); break;
        case 11: _t->slotPrintPreviewPaintRequested((*reinterpret_cast<std::add_pointer_t<QPrinter*>>(_a[1]))); break;
        case 12: _t->slotFilePrint(); break;
        case 13: _t->slotFileQuit(); break;
        case 14: _t->slotFileExportDocbook(); break;
        case 15: _t->slotFileExportXhtml(); break;
        case 16: _t->slotFind(); break;
        case 17: _t->slotFindNext(); break;
        case 18: _t->slotFindPrevious(); break;
        case 19: _t->slotEditCut(); break;
        case 20: _t->slotEditCopy(); break;
        case 21: _t->slotEditPaste(); break;
        case 22: _t->slotStatusMsg((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 23: _t->slotClassDiagram(); break;
        case 24: _t->slotObjectDiagram(); break;
        case 25: _t->slotSequenceDiagram(); break;
        case 26: _t->slotCollaborationDiagram(); break;
        case 27: _t->slotUseCaseDiagram(); break;
        case 28: _t->slotStateDiagram(); break;
        case 29: _t->slotActivityDiagram(); break;
        case 30: _t->slotComponentDiagram(); break;
        case 31: _t->slotDeploymentDiagram(); break;
        case 32: _t->slotEntityRelationshipDiagram(); break;
        case 33: _t->slotAlignLeft(); break;
        case 34: _t->slotAlignRight(); break;
        case 35: _t->slotAlignTop(); break;
        case 36: _t->slotAlignBottom(); break;
        case 37: _t->slotAlignVerticalMiddle(); break;
        case 38: _t->slotAlignHorizontalMiddle(); break;
        case 39: _t->slotAlignVerticalDistribute(); break;
        case 40: _t->slotAlignHorizontalDistribute(); break;
        case 41: _t->slotClipDataChanged(); break;
        case 42: _t->slotCopyChanged(); break;
        case 43: _t->slotPrefs((*reinterpret_cast<std::add_pointer_t<MultiPageDialogBase::PageType>>(_a[1]))); break;
        case 44: _t->slotPrefs(); break;
        case 45: _t->slotApplyPrefs(); break;
        case 46: _t->slotImportClass(); break;
        case 47: _t->slotImportProject(); break;
        case 48: _t->slotUpdateViews(); break;
        case 49: _t->slotCurrentViewClearDiagram(); break;
        case 50: _t->slotCurrentViewToggleSnapToGrid(); break;
        case 51: _t->slotCurrentViewToggleShowGrid(); break;
        case 52: _t->slotCurrentViewExportImage(); break;
        case 53: _t->slotViewsExportImages(); break;
        case 54: _t->slotCurrentProperties(); break;
        case 55: _t->slotClassWizard(); break;
        case 56: _t->slotAddDefaultDatatypes(); break;
        case 57: _t->slotCurrentViewChanged(); break;
        case 58: _t->slotSnapToGridToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 59: _t->slotShowGridToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 60: _t->slotSelectAll(); break;
        case 61: _t->slotDeleteSelected(); break;
        case 62: _t->slotDeleteDiagram(); break;
        case 63: _t->slotCloseDiagram((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 64: _t->slotGenerateAllCode(); break;
        case 65: _t->slotSetZoom((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 66: _t->slotZoomSliderMoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 67: _t->slotZoomFit(); break;
        case 68: _t->slotZoom100(); break;
        case 69: _t->slotZoomOut(); break;
        case 70: _t->slotZoomIn(); break;
        case 71: _t->slotBirdViewChanged((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 72: _t->setupZoomMenu(); break;
        case 73: _t->slotEditUndo(); break;
        case 74: _t->slotEditRedo(); break;
        case 75: _t->slotTabChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 76: _t->slotChangeTabLeft(); break;
        case 77: _t->slotChangeTabRight(); break;
        case 78: _t->slotMoveTabLeft(); break;
        case 79: _t->slotMoveTabRight(); break;
        case 80: _t->slotXhtmlDocGenerationFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 81: { bool _r = _t->slotOpenFileInEditor((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 82: { bool _r = _t->slotOpenFileInEditor((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 83: { bool _r = _t->slotOpenFileInEditor((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 84: _t->setLang_actionscript(); break;
        case 85: _t->setLang_ada(); break;
        case 86: _t->setLang_cpp(); break;
        case 87: _t->setLang_csharp(); break;
        case 88: _t->setLang_d(); break;
        case 89: _t->setLang_idl(); break;
        case 90: _t->setLang_java(); break;
        case 91: _t->setLang_javascript(); break;
        case 92: _t->setLang_mysql(); break;
        case 93: _t->setLang_pascal(); break;
        case 94: _t->setLang_perl(); break;
        case 95: _t->setLang_php(); break;
        case 96: _t->setLang_php5(); break;
        case 97: _t->setLang_postgresql(); break;
        case 98: _t->setLang_python(); break;
        case 99: _t->setLang_ruby(); break;
        case 100: _t->setLang_sql(); break;
        case 101: _t->setLang_tcl(); break;
        case 102: _t->setLang_vala(); break;
        case 103: _t->setLang_xmlschema(); break;
        case 104: _t->setLang_none(); break;
        case 105: _t->slotDiagramPopupMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 65:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UMLApp::*)()>(_a, &UMLApp::sigCutSuccessful, 0))
            return;
    }
}

const QMetaObject *UMLApp::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UMLApp::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6UMLAppE_t>.strings))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int UMLApp::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 106)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 106;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 106)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 106;
    }
    return _id;
}

// SIGNAL 0
void UMLApp::sigCutSuccessful()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
