/****************************************************************************
** Meta object code from reading C++ file 'dialogspopupmenu.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../umbrello-26.07.80/umbrello/menus/dialogspopupmenu.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dialogspopupmenu.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16DialogsPopupMenuE_t {};
} // unnamed namespace

template <> constexpr inline auto DialogsPopupMenu::qt_create_metaobjectdata<qt_meta_tag_ZN16DialogsPopupMenuE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DialogsPopupMenu",
        "TriggerType",
        "tt_Min",
        "tt_Activity_Selected",
        "tt_Association_Selected",
        "tt_Attribute_Selected",
        "tt_EntityAttribute_Selected",
        "tt_EnumLiteral_Selected",
        "tt_InstanceAttribute_Selected",
        "tt_New_Activity",
        "tt_New_Attribute",
        "tt_New_EntityAttribute",
        "tt_New_EnumLiteral",
        "tt_New_InstanceAttribute",
        "tt_New_Operation",
        "tt_New_Parameter",
        "tt_New_Template",
        "tt_Operation_Selected",
        "tt_Parameter_Selected",
        "tt_Template_Selected",
        "tt_Undefined",
        "tt_Max"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'TriggerType'
        QtMocHelpers::EnumData<enum TriggerType>(1, 1, QMC::EnumFlags{}).add({
            {    2, TriggerType::tt_Min },
            {    3, TriggerType::tt_Activity_Selected },
            {    4, TriggerType::tt_Association_Selected },
            {    5, TriggerType::tt_Attribute_Selected },
            {    6, TriggerType::tt_EntityAttribute_Selected },
            {    7, TriggerType::tt_EnumLiteral_Selected },
            {    8, TriggerType::tt_InstanceAttribute_Selected },
            {    9, TriggerType::tt_New_Activity },
            {   10, TriggerType::tt_New_Attribute },
            {   11, TriggerType::tt_New_EntityAttribute },
            {   12, TriggerType::tt_New_EnumLiteral },
            {   13, TriggerType::tt_New_InstanceAttribute },
            {   14, TriggerType::tt_New_Operation },
            {   15, TriggerType::tt_New_Parameter },
            {   16, TriggerType::tt_New_Template },
            {   17, TriggerType::tt_Operation_Selected },
            {   18, TriggerType::tt_Parameter_Selected },
            {   19, TriggerType::tt_Template_Selected },
            {   20, TriggerType::tt_Undefined },
            {   21, TriggerType::tt_Max },
        }),
    };
    return QtMocHelpers::metaObjectData<DialogsPopupMenu, qt_meta_tag_ZN16DialogsPopupMenuE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DialogsPopupMenu::staticMetaObject = { {
    QMetaObject::SuperData::link<ListPopupMenu::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16DialogsPopupMenuE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16DialogsPopupMenuE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16DialogsPopupMenuE_t>.metaTypes,
    nullptr
} };

void DialogsPopupMenu::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DialogsPopupMenu *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *DialogsPopupMenu::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DialogsPopupMenu::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16DialogsPopupMenuE_t>.strings))
        return static_cast<void*>(this);
    return ListPopupMenu::qt_metacast(_clname);
}

int DialogsPopupMenu::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ListPopupMenu::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
