/********************************************************************************
** Form generated from reading UI file 'codeimpselectpage.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CODEIMPSELECTPAGE_H
#define UI_CODEIMPSELECTPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_CodeImpSelectPage
{
public:
    QVBoxLayout *verticalLayout;
    QWidget *ui_inputWidget;
    QHBoxLayout *horizontalLayout;
    QHBoxLayout *ui_languageLayout;
    QLabel *ui_languageLabel;
    KComboBox *ui_languageBox;
    QSpacerItem *ui_languageSpacer;
    QCheckBox *ui_subdirCheckBox;
    QHBoxLayout *ui_fileExtLayout;
    QLabel *ui_fileExtLabel;
    QLineEdit *ui_fileExtLineEdit;
    QSpacerItem *ui_fileExtSpacer;
    QTreeView *ui_treeView;
    QHBoxLayout *ui_commandButtonLayout;
    QPushButton *ui_deselectAllButton;
    QPushButton *ui_selectAllButton;
    QFormLayout *ui_labelLayout;
    QLabel *ui_filesLabel;
    QLabel *ui_filesNumLabel;

    void setupUi(QWidget *CodeImpSelectPage)
    {
        if (CodeImpSelectPage->objectName().isEmpty())
            CodeImpSelectPage->setObjectName("CodeImpSelectPage");
        CodeImpSelectPage->resize(500, 539);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(CodeImpSelectPage->sizePolicy().hasHeightForWidth());
        CodeImpSelectPage->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(CodeImpSelectPage);
        verticalLayout->setObjectName("verticalLayout");
        ui_inputWidget = new QWidget(CodeImpSelectPage);
        ui_inputWidget->setObjectName("ui_inputWidget");
        horizontalLayout = new QHBoxLayout(ui_inputWidget);
        horizontalLayout->setSpacing(20);
        horizontalLayout->setObjectName("horizontalLayout");

        verticalLayout->addWidget(ui_inputWidget);

        ui_languageLayout = new QHBoxLayout();
        ui_languageLayout->setObjectName("ui_languageLayout");
        ui_languageLabel = new QLabel(CodeImpSelectPage);
        ui_languageLabel->setObjectName("ui_languageLabel");
        ui_languageLabel->setWordWrap(false);

        ui_languageLayout->addWidget(ui_languageLabel);

        ui_languageBox = new KComboBox(CodeImpSelectPage);
        ui_languageBox->setObjectName("ui_languageBox");

        ui_languageLayout->addWidget(ui_languageBox);

        ui_languageSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        ui_languageLayout->addItem(ui_languageSpacer);

        ui_subdirCheckBox = new QCheckBox(CodeImpSelectPage);
        ui_subdirCheckBox->setObjectName("ui_subdirCheckBox");

        ui_languageLayout->addWidget(ui_subdirCheckBox);


        verticalLayout->addLayout(ui_languageLayout);

        ui_fileExtLayout = new QHBoxLayout();
        ui_fileExtLayout->setObjectName("ui_fileExtLayout");
        ui_fileExtLabel = new QLabel(CodeImpSelectPage);
        ui_fileExtLabel->setObjectName("ui_fileExtLabel");

        ui_fileExtLayout->addWidget(ui_fileExtLabel);

        ui_fileExtLineEdit = new QLineEdit(CodeImpSelectPage);
        ui_fileExtLineEdit->setObjectName("ui_fileExtLineEdit");
        ui_fileExtLineEdit->setMaximumSize(QSize(180, 16777215));

        ui_fileExtLayout->addWidget(ui_fileExtLineEdit);

        ui_fileExtSpacer = new QSpacerItem(30, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        ui_fileExtLayout->addItem(ui_fileExtSpacer);


        verticalLayout->addLayout(ui_fileExtLayout);

        ui_treeView = new QTreeView(CodeImpSelectPage);
        ui_treeView->setObjectName("ui_treeView");

        verticalLayout->addWidget(ui_treeView);

        ui_commandButtonLayout = new QHBoxLayout();
        ui_commandButtonLayout->setSpacing(20);
        ui_commandButtonLayout->setObjectName("ui_commandButtonLayout");
        ui_deselectAllButton = new QPushButton(CodeImpSelectPage);
        ui_deselectAllButton->setObjectName("ui_deselectAllButton");

        ui_commandButtonLayout->addWidget(ui_deselectAllButton);

        ui_selectAllButton = new QPushButton(CodeImpSelectPage);
        ui_selectAllButton->setObjectName("ui_selectAllButton");

        ui_commandButtonLayout->addWidget(ui_selectAllButton);

        ui_labelLayout = new QFormLayout();
        ui_labelLayout->setObjectName("ui_labelLayout");
        ui_labelLayout->setFormAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        ui_filesLabel = new QLabel(CodeImpSelectPage);
        ui_filesLabel->setObjectName("ui_filesLabel");

        ui_labelLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, ui_filesLabel);

        ui_filesNumLabel = new QLabel(CodeImpSelectPage);
        ui_filesNumLabel->setObjectName("ui_filesNumLabel");

        ui_labelLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, ui_filesNumLabel);


        ui_commandButtonLayout->addLayout(ui_labelLayout);


        verticalLayout->addLayout(ui_commandButtonLayout);


        retranslateUi(CodeImpSelectPage);

        QMetaObject::connectSlotsByName(CodeImpSelectPage);
    } // setupUi

    void retranslateUi(QWidget *CodeImpSelectPage)
    {
        CodeImpSelectPage->setWindowTitle(tr2i18n("Code Generation Options", nullptr));
#if QT_CONFIG(tooltip)
        ui_languageLabel->setToolTip(tr2i18n("The language of the project.", nullptr));
#endif // QT_CONFIG(tooltip)
        ui_languageLabel->setText(tr2i18n("Programming Language:", nullptr));
        ui_subdirCheckBox->setText(tr2i18n("Include Subdirectories.", nullptr));
        ui_fileExtLabel->setText(tr2i18n("List of file extensions:", nullptr));
        ui_deselectAllButton->setText(tr2i18n("Deselect all", nullptr));
        ui_selectAllButton->setText(tr2i18n("Select all", nullptr));
        ui_filesLabel->setText(tr2i18n("Number of files:", nullptr));
        ui_filesNumLabel->setText(tr2i18n("0", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CodeImpSelectPage: public Ui_CodeImpSelectPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CODEIMPSELECTPAGE_H

