/****************************************************************************
** Meta object code from reading C++ file 'umlobject.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../umbrello-26.07.80/umbrello/umlmodel/umlobject.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'umlobject.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9UMLObjectE_t {};
} // unnamed namespace

template <> constexpr inline auto UMLObject::qt_create_metaobjectdata<qt_meta_tag_ZN9UMLObjectE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UMLObject",
        "modified",
        "",
        "emitModified",
        "ObjectType",
        "ot_Unknown",
        "ot_UMLObject",
        "ot_Actor",
        "ot_UseCase",
        "ot_Package",
        "ot_Interface",
        "ot_Datatype",
        "ot_Enum",
        "ot_Class",
        "ot_Instance",
        "ot_Association",
        "ot_Attribute",
        "ot_Operation",
        "ot_EnumLiteral",
        "ot_Template",
        "ot_Component",
        "ot_Artifact",
        "ot_Node",
        "ot_Stereotype",
        "ot_Role",
        "ot_Entity",
        "ot_EntityAttribute",
        "ot_Folder",
        "ot_EntityConstraint",
        "ot_UniqueConstraint",
        "ot_ForeignKeyConstraint",
        "ot_CheckConstraint",
        "ot_Category",
        "ot_Port",
        "ot_InstanceAttribute",
        "ot_SubSystem"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'modified'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'emitModified'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ObjectType'
        QtMocHelpers::EnumData<enum ObjectType>(4, 4, QMC::EnumFlags{}).add({
            {    5, ObjectType::ot_Unknown },
            {    6, ObjectType::ot_UMLObject },
            {    7, ObjectType::ot_Actor },
            {    8, ObjectType::ot_UseCase },
            {    9, ObjectType::ot_Package },
            {   10, ObjectType::ot_Interface },
            {   11, ObjectType::ot_Datatype },
            {   12, ObjectType::ot_Enum },
            {   13, ObjectType::ot_Class },
            {   14, ObjectType::ot_Instance },
            {   15, ObjectType::ot_Association },
            {   16, ObjectType::ot_Attribute },
            {   17, ObjectType::ot_Operation },
            {   18, ObjectType::ot_EnumLiteral },
            {   19, ObjectType::ot_Template },
            {   20, ObjectType::ot_Component },
            {   21, ObjectType::ot_Artifact },
            {   22, ObjectType::ot_Node },
            {   23, ObjectType::ot_Stereotype },
            {   24, ObjectType::ot_Role },
            {   25, ObjectType::ot_Entity },
            {   26, ObjectType::ot_EntityAttribute },
            {   27, ObjectType::ot_Folder },
            {   28, ObjectType::ot_EntityConstraint },
            {   29, ObjectType::ot_UniqueConstraint },
            {   30, ObjectType::ot_ForeignKeyConstraint },
            {   31, ObjectType::ot_CheckConstraint },
            {   32, ObjectType::ot_Category },
            {   33, ObjectType::ot_Port },
            {   34, ObjectType::ot_InstanceAttribute },
            {   35, ObjectType::ot_SubSystem },
        }),
    };
    return QtMocHelpers::metaObjectData<UMLObject, qt_meta_tag_ZN9UMLObjectE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UMLObject::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9UMLObjectE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9UMLObjectE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9UMLObjectE_t>.metaTypes,
    nullptr
} };

void UMLObject::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UMLObject *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->modified(); break;
        case 1: _t->emitModified(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UMLObject::*)()>(_a, &UMLObject::modified, 0))
            return;
    }
}

const QMetaObject *UMLObject::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UMLObject::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9UMLObjectE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int UMLObject::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void UMLObject::modified()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
