/********************************************************************************
** Form generated from reading UI file 'codevieweroptionsbase.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CODEVIEWEROPTIONSBASE_H
#define UI_CODEVIEWEROPTIONSBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KFontChooser"
#include "kcolorbutton.h"

QT_BEGIN_NAMESPACE

class Ui_CodeViewerOptionsBase
{
public:
    QGridLayout *gridLayout;
    KFontChooser *fontChooser;
    QGroupBox *colorGroupBox;
    QGridLayout *gridLayout1;
    QGridLayout *gridLayout2;
    QLabel *fontLabel;
    KColorButton *selectColorButton;
    QLabel *paperLabel;
    KColorButton *paperColorButton;
    QLabel *selectedLabel;
    KColorButton *fontColorButton;
    QGridLayout *gridLayout3;
    KColorButton *nonEditBlockColorButton;
    QGridLayout *gridLayout4;
    KColorButton *m_hiddenBlockColorButton;
    KColorButton *umlObjectColorButton;
    QLabel *textLabel1;
    QLabel *textLabel1_2;
    QLabel *textLabel2;
    KColorButton *editBlockColorButton;
    QLabel *textLabel3;

    void setupUi(QWidget *CodeViewerOptionsBase)
    {
        if (CodeViewerOptionsBase->objectName().isEmpty())
            CodeViewerOptionsBase->setObjectName("CodeViewerOptionsBase");
        CodeViewerOptionsBase->resize(486, 545);
        gridLayout = new QGridLayout(CodeViewerOptionsBase);
        gridLayout->setObjectName("gridLayout");
        fontChooser = new KFontChooser(CodeViewerOptionsBase);
        fontChooser->setObjectName("fontChooser");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(fontChooser->sizePolicy().hasHeightForWidth());
        fontChooser->setSizePolicy(sizePolicy);

        gridLayout->addWidget(fontChooser, 0, 0, 1, 1);

        colorGroupBox = new QGroupBox(CodeViewerOptionsBase);
        colorGroupBox->setObjectName("colorGroupBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(colorGroupBox->sizePolicy().hasHeightForWidth());
        colorGroupBox->setSizePolicy(sizePolicy1);
        gridLayout1 = new QGridLayout(colorGroupBox);
        gridLayout1->setObjectName("gridLayout1");
        gridLayout2 = new QGridLayout();
        gridLayout2->setObjectName("gridLayout2");
        fontLabel = new QLabel(colorGroupBox);
        fontLabel->setObjectName("fontLabel");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(fontLabel->sizePolicy().hasHeightForWidth());
        fontLabel->setSizePolicy(sizePolicy2);
        fontLabel->setWordWrap(false);

        gridLayout2->addWidget(fontLabel, 0, 2, 1, 1);

        selectColorButton = new KColorButton(colorGroupBox);
        selectColorButton->setObjectName("selectColorButton");
        selectColorButton->setColor(QColor(255, 255, 127));

        gridLayout2->addWidget(selectColorButton, 0, 5, 1, 1);

        paperLabel = new QLabel(colorGroupBox);
        paperLabel->setObjectName("paperLabel");
        sizePolicy2.setHeightForWidth(paperLabel->sizePolicy().hasHeightForWidth());
        paperLabel->setSizePolicy(sizePolicy2);
        paperLabel->setWordWrap(false);

        gridLayout2->addWidget(paperLabel, 0, 0, 1, 1);

        paperColorButton = new KColorButton(colorGroupBox);
        paperColorButton->setObjectName("paperColorButton");
        paperColorButton->setColor(QColor(255, 255, 255));

        gridLayout2->addWidget(paperColorButton, 0, 1, 1, 1);

        selectedLabel = new QLabel(colorGroupBox);
        selectedLabel->setObjectName("selectedLabel");
        sizePolicy2.setHeightForWidth(selectedLabel->sizePolicy().hasHeightForWidth());
        selectedLabel->setSizePolicy(sizePolicy2);
        selectedLabel->setWordWrap(false);

        gridLayout2->addWidget(selectedLabel, 0, 4, 1, 1);

        fontColorButton = new KColorButton(colorGroupBox);
        fontColorButton->setObjectName("fontColorButton");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(fontColorButton->sizePolicy().hasHeightForWidth());
        fontColorButton->setSizePolicy(sizePolicy3);
        fontColorButton->setColor(QColor(0, 0, 0));

        gridLayout2->addWidget(fontColorButton, 0, 3, 1, 1);


        gridLayout1->addLayout(gridLayout2, 0, 0, 1, 1);

        gridLayout3 = new QGridLayout();
        gridLayout3->setObjectName("gridLayout3");
        nonEditBlockColorButton = new KColorButton(colorGroupBox);
        nonEditBlockColorButton->setObjectName("nonEditBlockColorButton");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(nonEditBlockColorButton->sizePolicy().hasHeightForWidth());
        nonEditBlockColorButton->setSizePolicy(sizePolicy4);
        nonEditBlockColorButton->setColor(QColor(213, 213, 213));

        gridLayout3->addWidget(nonEditBlockColorButton, 1, 3, 1, 1);

        gridLayout4 = new QGridLayout();
        gridLayout4->setObjectName("gridLayout4");
        m_hiddenBlockColorButton = new KColorButton(colorGroupBox);
        m_hiddenBlockColorButton->setObjectName("m_hiddenBlockColorButton");
        sizePolicy4.setHeightForWidth(m_hiddenBlockColorButton->sizePolicy().hasHeightForWidth());
        m_hiddenBlockColorButton->setSizePolicy(sizePolicy4);
        m_hiddenBlockColorButton->setColor(QColor(166, 254, 248));

        gridLayout4->addWidget(m_hiddenBlockColorButton, 0, 3, 1, 1);

        umlObjectColorButton = new KColorButton(colorGroupBox);
        umlObjectColorButton->setObjectName("umlObjectColorButton");
        sizePolicy4.setHeightForWidth(umlObjectColorButton->sizePolicy().hasHeightForWidth());
        umlObjectColorButton->setSizePolicy(sizePolicy4);
        umlObjectColorButton->setColor(QColor(255, 170, 255));

        gridLayout4->addWidget(umlObjectColorButton, 0, 1, 1, 1);

        textLabel1 = new QLabel(colorGroupBox);
        textLabel1->setObjectName("textLabel1");
        sizePolicy2.setHeightForWidth(textLabel1->sizePolicy().hasHeightForWidth());
        textLabel1->setSizePolicy(sizePolicy2);
        textLabel1->setWordWrap(false);

        gridLayout4->addWidget(textLabel1, 0, 0, 1, 1);

        textLabel1_2 = new QLabel(colorGroupBox);
        textLabel1_2->setObjectName("textLabel1_2");
        sizePolicy2.setHeightForWidth(textLabel1_2->sizePolicy().hasHeightForWidth());
        textLabel1_2->setSizePolicy(sizePolicy2);
        textLabel1_2->setWordWrap(false);

        gridLayout4->addWidget(textLabel1_2, 0, 2, 1, 1);


        gridLayout3->addLayout(gridLayout4, 0, 0, 1, 4);

        textLabel2 = new QLabel(colorGroupBox);
        textLabel2->setObjectName("textLabel2");
        sizePolicy2.setHeightForWidth(textLabel2->sizePolicy().hasHeightForWidth());
        textLabel2->setSizePolicy(sizePolicy2);
        textLabel2->setWordWrap(false);

        gridLayout3->addWidget(textLabel2, 1, 2, 1, 1);

        editBlockColorButton = new KColorButton(colorGroupBox);
        editBlockColorButton->setObjectName("editBlockColorButton");
        sizePolicy4.setHeightForWidth(editBlockColorButton->sizePolicy().hasHeightForWidth());
        editBlockColorButton->setSizePolicy(sizePolicy4);
        editBlockColorButton->setColor(QColor(255, 170, 255));

        gridLayout3->addWidget(editBlockColorButton, 1, 1, 1, 1);

        textLabel3 = new QLabel(colorGroupBox);
        textLabel3->setObjectName("textLabel3");
        sizePolicy2.setHeightForWidth(textLabel3->sizePolicy().hasHeightForWidth());
        textLabel3->setSizePolicy(sizePolicy2);
        textLabel3->setWordWrap(false);

        gridLayout3->addWidget(textLabel3, 1, 0, 1, 1);


        gridLayout1->addLayout(gridLayout3, 1, 0, 1, 1);


        gridLayout->addWidget(colorGroupBox, 1, 0, 1, 1);


        retranslateUi(CodeViewerOptionsBase);

        QMetaObject::connectSlotsByName(CodeViewerOptionsBase);
    } // setupUi

    void retranslateUi(QWidget *CodeViewerOptionsBase)
    {
        colorGroupBox->setTitle(tr2i18n("Colors", nullptr));
        fontLabel->setText(tr2i18n("Font:", nullptr));
        selectColorButton->setText(QString());
        paperLabel->setText(tr2i18n("Paper:", nullptr));
        paperColorButton->setText(QString());
        selectedLabel->setText(tr2i18n("Selected:", nullptr));
        fontColorButton->setText(QString());
        nonEditBlockColorButton->setText(QString());
        m_hiddenBlockColorButton->setText(QString());
        umlObjectColorButton->setText(QString());
        textLabel1->setText(tr2i18n("<p align=\"right\">UML object block:</p>", nullptr));
        textLabel1_2->setText(tr2i18n("<p align=\"right\">Hidden block:</p>", nullptr));
        textLabel2->setText(tr2i18n("<p align=\"right\">Uneditable text:</p>", nullptr));
        editBlockColorButton->setText(QString());
        textLabel3->setText(tr2i18n("<p align=\"right\">Editable text:</p>", nullptr));
        (void)CodeViewerOptionsBase;
    } // retranslateUi

};

namespace Ui {
    class CodeViewerOptionsBase: public Ui_CodeViewerOptionsBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CODEVIEWEROPTIONSBASE_H

