/****************************************************************************
** Meta object code from reading C++ file 'worktoolbar.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../umbrello-26.07.80/umbrello/worktoolbar.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'worktoolbar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11WorkToolBarE_t {};
} // unnamed namespace

template <> constexpr inline auto WorkToolBar::qt_create_metaobjectdata<qt_meta_tag_ZN11WorkToolBarE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WorkToolBar",
        "sigButtonChanged",
        "",
        "slotCheckToolBar",
        "Uml::DiagramType::Enum",
        "dt",
        "buttonChanged",
        "b",
        "slotResetToolBar",
        "slotArrow",
        "slotGeneralization",
        "slotAggregation",
        "slotDependency",
        "slotAssociation",
        "slotContainment",
        "slotColl_Mesg_Sync",
        "slotColl_Mesg_Async",
        "slotSeq_Message_Creation",
        "slotSeq_Message_Destroy",
        "slotSeq_Message_Synchronous",
        "slotSeq_Message_Asynchronous",
        "slotSeq_Message_Found",
        "slotSeq_Message_Lost",
        "slotSeq_Combined_Fragment",
        "slotSeq_Precondition",
        "slotComposition",
        "slotRelationship",
        "slotUniAssociation",
        "slotState_Transition",
        "slotActivity_Transition",
        "slotAnchor",
        "slotNote",
        "slotBox",
        "slotText",
        "slotActor",
        "slotUseCase",
        "slotClass",
        "slotInterface",
        "slotInterfaceProvider",
        "slotInterfaceRequired",
        "slotDatatype",
        "slotEnum",
        "slotEntity",
        "slotPackage",
        "slotComponent",
        "slotNode",
        "slotArtifact",
        "slotObject",
        "slotRegion",
        "slotInitial_State",
        "slotState",
        "slotEnd_State",
        "slotInitial_Activity",
        "slotActivity",
        "slotEnd_Activity",
        "slotFinal_Activity",
        "slotBranch",
        "slotSend_Signal",
        "slotAccept_Signal",
        "slotAccept_Time_Event",
        "slotFork",
        "slotDeepHistory",
        "slotShallowHistory",
        "slotStateJoin",
        "slotStateFork",
        "slotJunction",
        "slotChoice",
        "slotAndline",
        "slotException",
        "slotPrePostCondition",
        "slotPin",
        "slotPort",
        "slotObject_Node",
        "slotCategory",
        "slotCategory2Parent",
        "slotChild2Category",
        "slotInstance",
        "slotSubsystem",
        "ToolBar_Buttons",
        "tbb_Undefined",
        "tbb_Arrow",
        "tbb_Generalization",
        "tbb_Aggregation",
        "tbb_Dependency",
        "tbb_Association",
        "tbb_Containment",
        "tbb_Coll_Mesg_Sync",
        "tbb_Coll_Mesg_Async",
        "tbb_Seq_Message_Creation",
        "tbb_Seq_Message_Destroy",
        "tbb_Seq_Message_Synchronous",
        "tbb_Seq_Message_Asynchronous",
        "tbb_Seq_Message_Found",
        "tbb_Seq_Message_Lost",
        "tbb_Seq_Combined_Fragment",
        "tbb_Seq_Precondition",
        "tbb_Composition",
        "tbb_Relationship",
        "tbb_UniAssociation",
        "tbb_State_Transition",
        "tbb_Activity_Transition",
        "tbb_Send_Signal",
        "tbb_Accept_Signal",
        "tbb_Accept_Time_Event",
        "tbb_Anchor",
        "tbb_Note",
        "tbb_Box",
        "tbb_Text",
        "tbb_Actor",
        "tbb_UseCase",
        "tbb_Class",
        "tbb_Interface",
        "tbb_Interface_Provider",
        "tbb_Interface_Requirement",
        "tbb_Datatype",
        "tbb_Enum",
        "tbb_Entity",
        "tbb_Package",
        "tbb_Component",
        "tbb_Node",
        "tbb_Artifact",
        "tbb_Object",
        "tbb_Initial_State",
        "tbb_State",
        "tbb_Region",
        "tbb_End_State",
        "tbb_Initial_Activity",
        "tbb_Activity",
        "tbb_End_Activity",
        "tbb_Final_Activity",
        "tbb_Pin",
        "tbb_Port",
        "tbb_Branch",
        "tbb_Fork",
        "tbb_DeepHistory",
        "tbb_ShallowHistory",
        "tbb_StateFork",
        "tbb_StateJoin",
        "tbb_Junction",
        "tbb_Choice",
        "tbb_Andline",
        "tbb_Exception",
        "tbb_Object_Node",
        "tbb_PrePostCondition",
        "tbb_Category",
        "tbb_Category2Parent",
        "tbb_Child2Category",
        "tbb_Instance",
        "tbb_SubSystem"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigButtonChanged'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotCheckToolBar'
        QtMocHelpers::SlotData<void(Uml::DiagramType::Enum)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'buttonChanged'
        QtMocHelpers::SlotData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'slotResetToolBar'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotArrow'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotGeneralization'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAggregation'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDependency'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAssociation'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotContainment'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotColl_Mesg_Sync'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotColl_Mesg_Async'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSeq_Message_Creation'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSeq_Message_Destroy'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSeq_Message_Synchronous'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSeq_Message_Asynchronous'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSeq_Message_Found'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSeq_Message_Lost'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSeq_Combined_Fragment'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSeq_Precondition'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotComposition'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRelationship'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotUniAssociation'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotState_Transition'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotActivity_Transition'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAnchor'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNote'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotBox'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotText'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotActor'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotUseCase'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotClass'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotInterface'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotInterfaceProvider'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotInterfaceRequired'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDatatype'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotEnum'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotEntity'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPackage'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotComponent'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNode'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotArtifact'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotObject'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRegion'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotInitial_State'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotState'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotEnd_State'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotInitial_Activity'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotActivity'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotEnd_Activity'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFinal_Activity'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotBranch'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSend_Signal'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAccept_Signal'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAccept_Time_Event'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFork'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDeepHistory'
        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotShallowHistory'
        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotStateJoin'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotStateFork'
        QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotJunction'
        QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotChoice'
        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAndline'
        QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotException'
        QtMocHelpers::SlotData<void()>(68, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPrePostCondition'
        QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPin'
        QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPort'
        QtMocHelpers::SlotData<void()>(71, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotObject_Node'
        QtMocHelpers::SlotData<void()>(72, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCategory'
        QtMocHelpers::SlotData<void()>(73, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCategory2Parent'
        QtMocHelpers::SlotData<void()>(74, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotChild2Category'
        QtMocHelpers::SlotData<void()>(75, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotInstance'
        QtMocHelpers::SlotData<void()>(76, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSubsystem'
        QtMocHelpers::SlotData<void()>(77, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ToolBar_Buttons'
        QtMocHelpers::EnumData<enum ToolBar_Buttons>(78, 78, QMC::EnumFlags{}).add({
            {   79, ToolBar_Buttons::tbb_Undefined },
            {   80, ToolBar_Buttons::tbb_Arrow },
            {   81, ToolBar_Buttons::tbb_Generalization },
            {   82, ToolBar_Buttons::tbb_Aggregation },
            {   83, ToolBar_Buttons::tbb_Dependency },
            {   84, ToolBar_Buttons::tbb_Association },
            {   85, ToolBar_Buttons::tbb_Containment },
            {   86, ToolBar_Buttons::tbb_Coll_Mesg_Sync },
            {   87, ToolBar_Buttons::tbb_Coll_Mesg_Async },
            {   88, ToolBar_Buttons::tbb_Seq_Message_Creation },
            {   89, ToolBar_Buttons::tbb_Seq_Message_Destroy },
            {   90, ToolBar_Buttons::tbb_Seq_Message_Synchronous },
            {   91, ToolBar_Buttons::tbb_Seq_Message_Asynchronous },
            {   92, ToolBar_Buttons::tbb_Seq_Message_Found },
            {   93, ToolBar_Buttons::tbb_Seq_Message_Lost },
            {   94, ToolBar_Buttons::tbb_Seq_Combined_Fragment },
            {   95, ToolBar_Buttons::tbb_Seq_Precondition },
            {   96, ToolBar_Buttons::tbb_Composition },
            {   97, ToolBar_Buttons::tbb_Relationship },
            {   98, ToolBar_Buttons::tbb_UniAssociation },
            {   99, ToolBar_Buttons::tbb_State_Transition },
            {  100, ToolBar_Buttons::tbb_Activity_Transition },
            {  101, ToolBar_Buttons::tbb_Send_Signal },
            {  102, ToolBar_Buttons::tbb_Accept_Signal },
            {  103, ToolBar_Buttons::tbb_Accept_Time_Event },
            {  104, ToolBar_Buttons::tbb_Anchor },
            {  105, ToolBar_Buttons::tbb_Note },
            {  106, ToolBar_Buttons::tbb_Box },
            {  107, ToolBar_Buttons::tbb_Text },
            {  108, ToolBar_Buttons::tbb_Actor },
            {  109, ToolBar_Buttons::tbb_UseCase },
            {  110, ToolBar_Buttons::tbb_Class },
            {  111, ToolBar_Buttons::tbb_Interface },
            {  112, ToolBar_Buttons::tbb_Interface_Provider },
            {  113, ToolBar_Buttons::tbb_Interface_Requirement },
            {  114, ToolBar_Buttons::tbb_Datatype },
            {  115, ToolBar_Buttons::tbb_Enum },
            {  116, ToolBar_Buttons::tbb_Entity },
            {  117, ToolBar_Buttons::tbb_Package },
            {  118, ToolBar_Buttons::tbb_Component },
            {  119, ToolBar_Buttons::tbb_Node },
            {  120, ToolBar_Buttons::tbb_Artifact },
            {  121, ToolBar_Buttons::tbb_Object },
            {  122, ToolBar_Buttons::tbb_Initial_State },
            {  123, ToolBar_Buttons::tbb_State },
            {  124, ToolBar_Buttons::tbb_Region },
            {  125, ToolBar_Buttons::tbb_End_State },
            {  126, ToolBar_Buttons::tbb_Initial_Activity },
            {  127, ToolBar_Buttons::tbb_Activity },
            {  128, ToolBar_Buttons::tbb_End_Activity },
            {  129, ToolBar_Buttons::tbb_Final_Activity },
            {  130, ToolBar_Buttons::tbb_Pin },
            {  131, ToolBar_Buttons::tbb_Port },
            {  132, ToolBar_Buttons::tbb_Branch },
            {  133, ToolBar_Buttons::tbb_Fork },
            {  134, ToolBar_Buttons::tbb_DeepHistory },
            {  135, ToolBar_Buttons::tbb_ShallowHistory },
            {  136, ToolBar_Buttons::tbb_StateFork },
            {  137, ToolBar_Buttons::tbb_StateJoin },
            {  138, ToolBar_Buttons::tbb_Junction },
            {  139, ToolBar_Buttons::tbb_Choice },
            {  140, ToolBar_Buttons::tbb_Andline },
            {  141, ToolBar_Buttons::tbb_Exception },
            {  142, ToolBar_Buttons::tbb_Object_Node },
            {  143, ToolBar_Buttons::tbb_PrePostCondition },
            {  144, ToolBar_Buttons::tbb_Category },
            {  145, ToolBar_Buttons::tbb_Category2Parent },
            {  146, ToolBar_Buttons::tbb_Child2Category },
            {  147, ToolBar_Buttons::tbb_Instance },
            {  148, ToolBar_Buttons::tbb_SubSystem },
        }),
    };
    return QtMocHelpers::metaObjectData<WorkToolBar, qt_meta_tag_ZN11WorkToolBarE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WorkToolBar::staticMetaObject = { {
    QMetaObject::SuperData::link<KToolBar::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11WorkToolBarE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11WorkToolBarE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11WorkToolBarE_t>.metaTypes,
    nullptr
} };

void WorkToolBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WorkToolBar *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigButtonChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->slotCheckToolBar((*reinterpret_cast<std::add_pointer_t<Uml::DiagramType::Enum>>(_a[1]))); break;
        case 2: _t->buttonChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->slotResetToolBar(); break;
        case 4: _t->slotArrow(); break;
        case 5: _t->slotGeneralization(); break;
        case 6: _t->slotAggregation(); break;
        case 7: _t->slotDependency(); break;
        case 8: _t->slotAssociation(); break;
        case 9: _t->slotContainment(); break;
        case 10: _t->slotColl_Mesg_Sync(); break;
        case 11: _t->slotColl_Mesg_Async(); break;
        case 12: _t->slotSeq_Message_Creation(); break;
        case 13: _t->slotSeq_Message_Destroy(); break;
        case 14: _t->slotSeq_Message_Synchronous(); break;
        case 15: _t->slotSeq_Message_Asynchronous(); break;
        case 16: _t->slotSeq_Message_Found(); break;
        case 17: _t->slotSeq_Message_Lost(); break;
        case 18: _t->slotSeq_Combined_Fragment(); break;
        case 19: _t->slotSeq_Precondition(); break;
        case 20: _t->slotComposition(); break;
        case 21: _t->slotRelationship(); break;
        case 22: _t->slotUniAssociation(); break;
        case 23: _t->slotState_Transition(); break;
        case 24: _t->slotActivity_Transition(); break;
        case 25: _t->slotAnchor(); break;
        case 26: _t->slotNote(); break;
        case 27: _t->slotBox(); break;
        case 28: _t->slotText(); break;
        case 29: _t->slotActor(); break;
        case 30: _t->slotUseCase(); break;
        case 31: _t->slotClass(); break;
        case 32: _t->slotInterface(); break;
        case 33: _t->slotInterfaceProvider(); break;
        case 34: _t->slotInterfaceRequired(); break;
        case 35: _t->slotDatatype(); break;
        case 36: _t->slotEnum(); break;
        case 37: _t->slotEntity(); break;
        case 38: _t->slotPackage(); break;
        case 39: _t->slotComponent(); break;
        case 40: _t->slotNode(); break;
        case 41: _t->slotArtifact(); break;
        case 42: _t->slotObject(); break;
        case 43: _t->slotRegion(); break;
        case 44: _t->slotInitial_State(); break;
        case 45: _t->slotState(); break;
        case 46: _t->slotEnd_State(); break;
        case 47: _t->slotInitial_Activity(); break;
        case 48: _t->slotActivity(); break;
        case 49: _t->slotEnd_Activity(); break;
        case 50: _t->slotFinal_Activity(); break;
        case 51: _t->slotBranch(); break;
        case 52: _t->slotSend_Signal(); break;
        case 53: _t->slotAccept_Signal(); break;
        case 54: _t->slotAccept_Time_Event(); break;
        case 55: _t->slotFork(); break;
        case 56: _t->slotDeepHistory(); break;
        case 57: _t->slotShallowHistory(); break;
        case 58: _t->slotStateJoin(); break;
        case 59: _t->slotStateFork(); break;
        case 60: _t->slotJunction(); break;
        case 61: _t->slotChoice(); break;
        case 62: _t->slotAndline(); break;
        case 63: _t->slotException(); break;
        case 64: _t->slotPrePostCondition(); break;
        case 65: _t->slotPin(); break;
        case 66: _t->slotPort(); break;
        case 67: _t->slotObject_Node(); break;
        case 68: _t->slotCategory(); break;
        case 69: _t->slotCategory2Parent(); break;
        case 70: _t->slotChild2Category(); break;
        case 71: _t->slotInstance(); break;
        case 72: _t->slotSubsystem(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WorkToolBar::*)(int )>(_a, &WorkToolBar::sigButtonChanged, 0))
            return;
    }
}

const QMetaObject *WorkToolBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WorkToolBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11WorkToolBarE_t>.strings))
        return static_cast<void*>(this);
    return KToolBar::qt_metacast(_clname);
}

int WorkToolBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KToolBar::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 73)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 73;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 73)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 73;
    }
    return _id;
}

// SIGNAL 0
void WorkToolBar::sigButtonChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
