/********************************************************************************
** Form generated from reading UI file 'codeviewerdialogbase.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CODEVIEWERDIALOGBASE_H
#define UI_CODEVIEWERDIALOGBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_CodeViewerDialogBase
{
public:
    QVBoxLayout *vboxLayout;
    QVBoxLayout *vboxLayout1;
    QGridLayout *gridLayout;
    QCheckBox *ui_showHiddenCodeCB;
    QLabel *ui_componentLabel;
    QCheckBox *ui_highlightCheckBox;
    QTabWidget *ui_tabWidget;

    void setupUi(QWidget *CodeViewerDialogBase)
    {
        if (CodeViewerDialogBase->objectName().isEmpty())
            CodeViewerDialogBase->setObjectName("CodeViewerDialogBase");
        CodeViewerDialogBase->resize(615, 658);
        vboxLayout = new QVBoxLayout(CodeViewerDialogBase);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout1 = new QVBoxLayout();
        vboxLayout1->setObjectName("vboxLayout1");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        ui_showHiddenCodeCB = new QCheckBox(CodeViewerDialogBase);
        ui_showHiddenCodeCB->setObjectName("ui_showHiddenCodeCB");

        gridLayout->addWidget(ui_showHiddenCodeCB, 0, 1, 1, 1);

        ui_componentLabel = new QLabel(CodeViewerDialogBase);
        ui_componentLabel->setObjectName("ui_componentLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ui_componentLabel->sizePolicy().hasHeightForWidth());
        ui_componentLabel->setSizePolicy(sizePolicy);
        ui_componentLabel->setScaledContents(true);
        ui_componentLabel->setWordWrap(false);

        gridLayout->addWidget(ui_componentLabel, 1, 0, 1, 3);

        ui_highlightCheckBox = new QCheckBox(CodeViewerDialogBase);
        ui_highlightCheckBox->setObjectName("ui_highlightCheckBox");
        ui_highlightCheckBox->setChecked(false);

        gridLayout->addWidget(ui_highlightCheckBox, 0, 0, 1, 1);


        vboxLayout1->addLayout(gridLayout);

        ui_tabWidget = new QTabWidget(CodeViewerDialogBase);
        ui_tabWidget->setObjectName("ui_tabWidget");

        vboxLayout1->addWidget(ui_tabWidget);


        vboxLayout->addLayout(vboxLayout1);


        retranslateUi(CodeViewerDialogBase);

        QMetaObject::connectSlotsByName(CodeViewerDialogBase);
    } // setupUi

    void retranslateUi(QWidget *CodeViewerDialogBase)
    {
        ui_showHiddenCodeCB->setText(tr2i18n("Show hidden blocks", nullptr));
        ui_componentLabel->setText(tr2i18n("<p align=\"center\">component name here</p>", nullptr));
        ui_highlightCheckBox->setText(tr2i18n("Show block type", nullptr));
        (void)CodeViewerDialogBase;
    } // retranslateUi

};

namespace Ui {
    class CodeViewerDialogBase: public Ui_CodeViewerDialogBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CODEVIEWERDIALOGBASE_H

