/****************************************************************************
** Meta object code from reading C++ file 'multipagedialogbase.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../umbrello-26.07.80/umbrello/dialogs/multipagedialogbase.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'multipagedialogbase.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19MultiPageDialogBaseE_t {};
} // unnamed namespace

template <> constexpr inline auto MultiPageDialogBase::qt_create_metaobjectdata<qt_meta_tag_ZN19MultiPageDialogBaseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MultiPageDialogBase",
        "okClicked",
        "",
        "applyClicked",
        "defaultClicked",
        "slotEnableButtonOk",
        "state",
        "slotOkClicked",
        "slotApplyClicked",
        "slotDefaultClicked",
        "slotHelpClicked",
        "slotButtonClicked",
        "QAbstractButton*",
        "button"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'okClicked'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'applyClicked'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultClicked'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotEnableButtonOk'
        QtMocHelpers::SlotData<void(bool)>(5, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Slot 'slotOkClicked'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotApplyClicked'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDefaultClicked'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotHelpClicked'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotButtonClicked'
        QtMocHelpers::SlotData<void(QAbstractButton *)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MultiPageDialogBase, qt_meta_tag_ZN19MultiPageDialogBaseE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MultiPageDialogBase::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19MultiPageDialogBaseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19MultiPageDialogBaseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19MultiPageDialogBaseE_t>.metaTypes,
    nullptr
} };

void MultiPageDialogBase::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MultiPageDialogBase *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->okClicked(); break;
        case 1: _t->applyClicked(); break;
        case 2: _t->defaultClicked(); break;
        case 3: _t->slotEnableButtonOk((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->slotOkClicked(); break;
        case 5: _t->slotApplyClicked(); break;
        case 6: _t->slotDefaultClicked(); break;
        case 7: _t->slotHelpClicked(); break;
        case 8: _t->slotButtonClicked((*reinterpret_cast<std::add_pointer_t<QAbstractButton*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MultiPageDialogBase::*)()>(_a, &MultiPageDialogBase::okClicked, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultiPageDialogBase::*)()>(_a, &MultiPageDialogBase::applyClicked, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MultiPageDialogBase::*)()>(_a, &MultiPageDialogBase::defaultClicked, 2))
            return;
    }
}

const QMetaObject *MultiPageDialogBase::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MultiPageDialogBase::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19MultiPageDialogBaseE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int MultiPageDialogBase::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void MultiPageDialogBase::okClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MultiPageDialogBase::applyClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void MultiPageDialogBase::defaultClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
