/********************************************************************************
** Form generated from reading UI file 'autolayoutoptionpage.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_AUTOLAYOUTOPTIONPAGE_H
#define UI_AUTOLAYOUTOPTIONPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_AutoLayoutOptionPage
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QCheckBox *m_autoDotPath;
    QLabel *label;
    KUrlRequester *m_dotPath;
    QSpacerItem *verticalSpacer_2;
    QGroupBox *Other;
    QGridLayout *gridLayout_2;
    QCheckBox *m_showExportLayout;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *AutoLayoutOptionPage)
    {
        if (AutoLayoutOptionPage->objectName().isEmpty())
            AutoLayoutOptionPage->setObjectName("AutoLayoutOptionPage");
        AutoLayoutOptionPage->resize(539, 270);
        vboxLayout = new QVBoxLayout(AutoLayoutOptionPage);
        vboxLayout->setObjectName("vboxLayout");
        groupBox = new QGroupBox(AutoLayoutOptionPage);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        m_autoDotPath = new QCheckBox(groupBox);
        m_autoDotPath->setObjectName("m_autoDotPath");
        m_autoDotPath->setChecked(true);

        gridLayout->addWidget(m_autoDotPath, 0, 0, 1, 1);

        label = new QLabel(groupBox);
        label->setObjectName("label");

        gridLayout->addWidget(label, 2, 0, 1, 1);

        m_dotPath = new KUrlRequester(groupBox);
        m_dotPath->setObjectName("m_dotPath");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_dotPath->sizePolicy().hasHeightForWidth());
        m_dotPath->setSizePolicy(sizePolicy);
        m_dotPath->setSizeIncrement(QSize(10, 0));
        m_dotPath->setMode(KFile::Directory|KFile::ExistingOnly);

        gridLayout->addWidget(m_dotPath, 3, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_2, 1, 0, 1, 1);


        vboxLayout->addWidget(groupBox);

        Other = new QGroupBox(AutoLayoutOptionPage);
        Other->setObjectName("Other");
        gridLayout_2 = new QGridLayout(Other);
        gridLayout_2->setObjectName("gridLayout_2");
        m_showExportLayout = new QCheckBox(Other);
        m_showExportLayout->setObjectName("m_showExportLayout");

        gridLayout_2->addWidget(m_showExportLayout, 1, 0, 1, 1);


        vboxLayout->addWidget(Other);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(verticalSpacer);


        retranslateUi(AutoLayoutOptionPage);
        QObject::connect(m_autoDotPath, SIGNAL(toggled(bool)), m_dotPath, SLOT(setDisabled(bool)));

        QMetaObject::connectSlotsByName(AutoLayoutOptionPage);
    } // setupUi

    void retranslateUi(QWidget *AutoLayoutOptionPage)
    {
        groupBox->setTitle(tr2i18n("Layout Generator", nullptr));
#if QT_CONFIG(tooltip)
        m_autoDotPath->setToolTip(tr2i18n("<p>The auto layout feature depends on layout generators provided by the GraphViz package, which is normally installed aside Umbrello by a package manager.</p>\n"
"<p>Umbrello has built in support for detecting the install location of  these layout generators. For cases where this dependency is not available or do not fit, a different installation path could be provided.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        m_autoDotPath->setText(tr2i18n("Auto detect layout generator", nullptr));
        label->setText(tr2i18n("Generator executable path:", nullptr));
        Other->setTitle(tr2i18n("Miscellaneous", nullptr));
#if QT_CONFIG(tooltip)
        m_showExportLayout->setToolTip(tr2i18n("<p>Dot file export is performed by using the export layout.</p><p>With this option checked, the export layout is added to the list of available diagram layouts and enables a quick dot export preview.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        m_showExportLayout->setText(tr2i18n("Show export layout in diagram context menu", nullptr));
        (void)AutoLayoutOptionPage;
    } // retranslateUi

};

namespace Ui {
    class AutoLayoutOptionPage: public Ui_AutoLayoutOptionPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // AUTOLAYOUTOPTIONPAGE_H

