/****************************************************************************
** Meta object code from reading C++ file 'codeimpstatuspage.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../umbrello-26.07.80/umbrello/codeimpwizard/codeimpstatuspage.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'codeimpstatuspage.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17CodeImpStatusPageE_t {};
} // unnamed namespace

template <> constexpr inline auto CodeImpStatusPage::qt_create_metaobjectdata<qt_meta_tag_ZN17CodeImpStatusPageE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CodeImpStatusPage",
        "importCode",
        "",
        "importCodeFile",
        "noError",
        "importNextFile",
        "importCodeFinish",
        "importCodeStop",
        "updateStatus",
        "file",
        "text",
        "messageToLog",
        "messageToApp",
        "populateStatusList",
        "loggerClear",
        "loggerExport"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'importCode'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'importCodeFile'
        QtMocHelpers::SlotData<void(bool)>(3, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Slot 'importCodeFile'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessProtected | QMC::MethodCloned, QMetaType::Void),
        // Slot 'importNextFile'
        QtMocHelpers::SlotData<void(bool)>(5, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Slot 'importNextFile'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessProtected | QMC::MethodCloned, QMetaType::Void),
        // Slot 'importCodeFinish'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'importCodeStop'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'updateStatus'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(8, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 10 },
        }}),
        // Slot 'messageToLog'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(11, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 10 },
        }}),
        // Slot 'messageToApp'
        QtMocHelpers::SlotData<void(const QString &)>(12, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'populateStatusList'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'loggerClear'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'loggerExport'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CodeImpStatusPage, qt_meta_tag_ZN17CodeImpStatusPageE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CodeImpStatusPage::staticMetaObject = { {
    QMetaObject::SuperData::link<QWizardPage::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17CodeImpStatusPageE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17CodeImpStatusPageE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17CodeImpStatusPageE_t>.metaTypes,
    nullptr
} };

void CodeImpStatusPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CodeImpStatusPage *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->importCode(); break;
        case 1: _t->importCodeFile((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->importCodeFile(); break;
        case 3: _t->importNextFile((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->importNextFile(); break;
        case 5: _t->importCodeFinish(); break;
        case 6: _t->importCodeStop(); break;
        case 7: _t->updateStatus((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 8: _t->messageToLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 9: _t->messageToApp((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->populateStatusList(); break;
        case 11: _t->loggerClear(); break;
        case 12: _t->loggerExport(); break;
        default: ;
        }
    }
}

const QMetaObject *CodeImpStatusPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CodeImpStatusPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17CodeImpStatusPageE_t>.strings))
        return static_cast<void*>(this);
    return QWizardPage::qt_metacast(_clname);
}

int CodeImpStatusPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWizardPage::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN10CodeImport9LedStatusE_t {};
} // unnamed namespace

template <> constexpr inline auto CodeImport::LedStatus::qt_create_metaobjectdata<qt_meta_tag_ZN10CodeImport9LedStatusE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CodeImport::LedStatus"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LedStatus, qt_meta_tag_ZN10CodeImport9LedStatusE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CodeImport::LedStatus::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10CodeImport9LedStatusE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10CodeImport9LedStatusE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10CodeImport9LedStatusE_t>.metaTypes,
    nullptr
} };

void CodeImport::LedStatus::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LedStatus *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *CodeImport::LedStatus::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CodeImport::LedStatus::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10CodeImport9LedStatusE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int CodeImport::LedStatus::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
