/********************************************************************************
** Form generated from reading UI file 'javacodegenerationformbase.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_JAVACODEGENERATIONFORMBASE_H
#define UI_JAVACODEGENERATIONFORMBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_JavaCodeGenerationFormBase
{
public:
    QGridLayout *gridLayout;
    QGridLayout *gridLayout1;
    QGroupBox *groupBox3;
    QVBoxLayout *vboxLayout;
    QCheckBox *m_makeANTDocumentCheckBox;
    QGroupBox *groupBox2;
    QGridLayout *gridLayout2;
    QGridLayout *gridLayout3;
    QCheckBox *m_generateConstructors;
    QCheckBox *m_generateAssocAccessors;
    QCheckBox *m_generateAttribAccessors;
    QGridLayout *gridLayout4;
    QLabel *textLabel1_3;
    KComboBox *m_accessorScopeCB;
    QGridLayout *gridLayout5;
    QLabel *ui_textLabelAssFieldScope;
    KComboBox *m_assocFieldScopeCB;
    QGroupBox *groupBox1;
    QHBoxLayout *hboxLayout;
    QLabel *ui_textLabelStyle;
    KComboBox *m_SelectCommentStyle;
    QLabel *ui_textLabelTitle;

    void setupUi(QWidget *JavaCodeGenerationFormBase)
    {
        if (JavaCodeGenerationFormBase->objectName().isEmpty())
            JavaCodeGenerationFormBase->setObjectName("JavaCodeGenerationFormBase");
        JavaCodeGenerationFormBase->resize(462, 375);
        gridLayout = new QGridLayout(JavaCodeGenerationFormBase);
        gridLayout->setObjectName("gridLayout");
        gridLayout1 = new QGridLayout();
        gridLayout1->setObjectName("gridLayout1");
        gridLayout1->setContentsMargins(0, 0, 0, 0);
        groupBox3 = new QGroupBox(JavaCodeGenerationFormBase);
        groupBox3->setObjectName("groupBox3");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(groupBox3->sizePolicy().hasHeightForWidth());
        groupBox3->setSizePolicy(sizePolicy);
        groupBox3->setMaximumSize(QSize(16777215, 50));
        vboxLayout = new QVBoxLayout(groupBox3);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(4, 0, 4, 0);
        m_makeANTDocumentCheckBox = new QCheckBox(groupBox3);
        m_makeANTDocumentCheckBox->setObjectName("m_makeANTDocumentCheckBox");

        vboxLayout->addWidget(m_makeANTDocumentCheckBox);


        gridLayout1->addWidget(groupBox3, 3, 0, 1, 1);

        groupBox2 = new QGroupBox(JavaCodeGenerationFormBase);
        groupBox2->setObjectName("groupBox2");
        sizePolicy.setHeightForWidth(groupBox2->sizePolicy().hasHeightForWidth());
        groupBox2->setSizePolicy(sizePolicy);
        gridLayout2 = new QGridLayout(groupBox2);
        gridLayout2->setObjectName("gridLayout2");
        gridLayout2->setContentsMargins(0, 0, 0, 0);
        gridLayout3 = new QGridLayout();
        gridLayout3->setObjectName("gridLayout3");
        gridLayout3->setContentsMargins(4, 0, 4, 0);
        m_generateConstructors = new QCheckBox(groupBox2);
        m_generateConstructors->setObjectName("m_generateConstructors");
        m_generateConstructors->setChecked(false);

        gridLayout3->addWidget(m_generateConstructors, 0, 0, 1, 1);

        m_generateAssocAccessors = new QCheckBox(groupBox2);
        m_generateAssocAccessors->setObjectName("m_generateAssocAccessors");
        m_generateAssocAccessors->setChecked(true);

        gridLayout3->addWidget(m_generateAssocAccessors, 2, 0, 1, 1);

        m_generateAttribAccessors = new QCheckBox(groupBox2);
        m_generateAttribAccessors->setObjectName("m_generateAttribAccessors");
        m_generateAttribAccessors->setChecked(true);

        gridLayout3->addWidget(m_generateAttribAccessors, 1, 0, 1, 1);


        gridLayout2->addLayout(gridLayout3, 0, 0, 1, 1);

        gridLayout4 = new QGridLayout();
        gridLayout4->setObjectName("gridLayout4");
        gridLayout4->setContentsMargins(4, 0, 4, 0);
        textLabel1_3 = new QLabel(groupBox2);
        textLabel1_3->setObjectName("textLabel1_3");
        textLabel1_3->setWordWrap(false);

        gridLayout4->addWidget(textLabel1_3, 0, 0, 1, 1);

        m_accessorScopeCB = new KComboBox(groupBox2);
        m_accessorScopeCB->addItem(QString());
        m_accessorScopeCB->addItem(QString());
        m_accessorScopeCB->addItem(QString());
        m_accessorScopeCB->addItem(QString());
        m_accessorScopeCB->setObjectName("m_accessorScopeCB");

        gridLayout4->addWidget(m_accessorScopeCB, 0, 1, 1, 1);


        gridLayout2->addLayout(gridLayout4, 1, 0, 1, 1);

        gridLayout5 = new QGridLayout();
        gridLayout5->setObjectName("gridLayout5");
        gridLayout5->setContentsMargins(4, 0, 4, 0);
        ui_textLabelAssFieldScope = new QLabel(groupBox2);
        ui_textLabelAssFieldScope->setObjectName("ui_textLabelAssFieldScope");
        ui_textLabelAssFieldScope->setWordWrap(false);

        gridLayout5->addWidget(ui_textLabelAssFieldScope, 0, 0, 1, 1);

        m_assocFieldScopeCB = new KComboBox(groupBox2);
        m_assocFieldScopeCB->addItem(QString());
        m_assocFieldScopeCB->addItem(QString());
        m_assocFieldScopeCB->addItem(QString());
        m_assocFieldScopeCB->addItem(QString());
        m_assocFieldScopeCB->setObjectName("m_assocFieldScopeCB");

        gridLayout5->addWidget(m_assocFieldScopeCB, 0, 1, 1, 1);


        gridLayout2->addLayout(gridLayout5, 2, 0, 1, 1);


        gridLayout1->addWidget(groupBox2, 2, 0, 1, 1);

        groupBox1 = new QGroupBox(JavaCodeGenerationFormBase);
        groupBox1->setObjectName("groupBox1");
        sizePolicy.setHeightForWidth(groupBox1->sizePolicy().hasHeightForWidth());
        groupBox1->setSizePolicy(sizePolicy);
        groupBox1->setMaximumSize(QSize(16777215, 100));
        hboxLayout = new QHBoxLayout(groupBox1);
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(4, 0, 4, 0);
        ui_textLabelStyle = new QLabel(groupBox1);
        ui_textLabelStyle->setObjectName("ui_textLabelStyle");
        ui_textLabelStyle->setWordWrap(false);

        hboxLayout->addWidget(ui_textLabelStyle);

        m_SelectCommentStyle = new KComboBox(groupBox1);
        m_SelectCommentStyle->addItem(QString());
        m_SelectCommentStyle->addItem(QString());
        m_SelectCommentStyle->setObjectName("m_SelectCommentStyle");

        hboxLayout->addWidget(m_SelectCommentStyle);


        gridLayout1->addWidget(groupBox1, 1, 0, 1, 1);

        ui_textLabelTitle = new QLabel(JavaCodeGenerationFormBase);
        ui_textLabelTitle->setObjectName("ui_textLabelTitle");
        sizePolicy.setHeightForWidth(ui_textLabelTitle->sizePolicy().hasHeightForWidth());
        ui_textLabelTitle->setSizePolicy(sizePolicy);
        ui_textLabelTitle->setMaximumSize(QSize(16777215, 40));
        ui_textLabelTitle->setWordWrap(false);

        gridLayout1->addWidget(ui_textLabelTitle, 0, 0, 1, 1);


        gridLayout->addLayout(gridLayout1, 0, 0, 1, 1);


        retranslateUi(JavaCodeGenerationFormBase);

        m_accessorScopeCB->setCurrentIndex(3);
        m_assocFieldScopeCB->setCurrentIndex(3);


        QMetaObject::connectSlotsByName(JavaCodeGenerationFormBase);
    } // setupUi

    void retranslateUi(QWidget *JavaCodeGenerationFormBase)
    {
        groupBox3->setTitle(tr2i18n("Project Generation", nullptr));
        m_makeANTDocumentCheckBox->setText(tr2i18n("Create ANT build document", nullptr));
        groupBox2->setTitle(tr2i18n("Auto-Generate Methods", nullptr));
        m_generateConstructors->setText(tr2i18n("Empty constructor methods", nullptr));
        m_generateAssocAccessors->setText(tr2i18n("Association accessor methods", nullptr));
        m_generateAttribAccessors->setText(tr2i18n("Attribute accessor methods", nullptr));
        textLabel1_3->setText(tr2i18n("Default attribute accessor scope:", nullptr));
        m_accessorScopeCB->setItemText(0, tr2i18n("Public", nullptr));
        m_accessorScopeCB->setItemText(1, tr2i18n("Private", nullptr));
        m_accessorScopeCB->setItemText(2, tr2i18n("Protected", nullptr));
        m_accessorScopeCB->setItemText(3, tr2i18n("From Parent Object", nullptr));

        ui_textLabelAssFieldScope->setText(tr2i18n("Default association field scope:", nullptr));
        m_assocFieldScopeCB->setItemText(0, tr2i18n("Public", nullptr));
        m_assocFieldScopeCB->setItemText(1, tr2i18n("Private", nullptr));
        m_assocFieldScopeCB->setItemText(2, tr2i18n("Protected", nullptr));
        m_assocFieldScopeCB->setItemText(3, tr2i18n("From Parent Role", nullptr));

        groupBox1->setTitle(tr2i18n("Documentation", nullptr));
        ui_textLabelStyle->setText(tr2i18n("Style:", nullptr));
        m_SelectCommentStyle->setItemText(0, tr2i18n("Slash-Slash (//)", nullptr));
        m_SelectCommentStyle->setItemText(1, tr2i18n("Slash-Star (/**  */)", nullptr));

        ui_textLabelTitle->setText(tr2i18n("<p align=\"center\">Java Code Generation</p>", nullptr));
        (void)JavaCodeGenerationFormBase;
    } // retranslateUi

};

namespace Ui {
    class JavaCodeGenerationFormBase: public Ui_JavaCodeGenerationFormBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // JAVACODEGENERATIONFORMBASE_H

