/****************************************************************************
** Meta object code from reading C++ file 'widgetbase.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../umbrello-26.07.80/umbrello/umlwidgets/widgetbase.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'widgetbase.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10WidgetBaseE_t {};
} // unnamed namespace

template <> constexpr inline auto WidgetBase::qt_create_metaobjectdata<qt_meta_tag_ZN10WidgetBaseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WidgetBase",
        "slotMenuSelection",
        "",
        "QAction*",
        "trigger",
        "WidgetType",
        "wt_Min",
        "wt_UMLWidget",
        "wt_Actor",
        "wt_UseCase",
        "wt_Class",
        "wt_Interface",
        "wt_Datatype",
        "wt_Enum",
        "wt_Entity",
        "wt_Package",
        "wt_Object",
        "wt_Note",
        "wt_Box",
        "wt_Message",
        "wt_Text",
        "wt_State",
        "wt_Activity",
        "wt_Component",
        "wt_Artifact",
        "wt_Node",
        "wt_Association",
        "wt_ForkJoin",
        "wt_Precondition",
        "wt_CombinedFragment",
        "wt_FloatingDashLine",
        "wt_Signal",
        "wt_Pin",
        "wt_ObjectNode",
        "wt_Region",
        "wt_Category",
        "wt_Port",
        "wt_Instance",
        "wt_Max"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotMenuSelection'
        QtMocHelpers::SlotData<void(QAction *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'WidgetType'
        QtMocHelpers::EnumData<enum WidgetType>(5, 5, QMC::EnumFlags{}).add({
            {    6, WidgetType::wt_Min },
            {    7, WidgetType::wt_UMLWidget },
            {    8, WidgetType::wt_Actor },
            {    9, WidgetType::wt_UseCase },
            {   10, WidgetType::wt_Class },
            {   11, WidgetType::wt_Interface },
            {   12, WidgetType::wt_Datatype },
            {   13, WidgetType::wt_Enum },
            {   14, WidgetType::wt_Entity },
            {   15, WidgetType::wt_Package },
            {   16, WidgetType::wt_Object },
            {   17, WidgetType::wt_Note },
            {   18, WidgetType::wt_Box },
            {   19, WidgetType::wt_Message },
            {   20, WidgetType::wt_Text },
            {   21, WidgetType::wt_State },
            {   22, WidgetType::wt_Activity },
            {   23, WidgetType::wt_Component },
            {   24, WidgetType::wt_Artifact },
            {   25, WidgetType::wt_Node },
            {   26, WidgetType::wt_Association },
            {   27, WidgetType::wt_ForkJoin },
            {   28, WidgetType::wt_Precondition },
            {   29, WidgetType::wt_CombinedFragment },
            {   30, WidgetType::wt_FloatingDashLine },
            {   31, WidgetType::wt_Signal },
            {   32, WidgetType::wt_Pin },
            {   33, WidgetType::wt_ObjectNode },
            {   34, WidgetType::wt_Region },
            {   35, WidgetType::wt_Category },
            {   36, WidgetType::wt_Port },
            {   37, WidgetType::wt_Instance },
            {   38, WidgetType::wt_Max },
        }),
    };
    return QtMocHelpers::metaObjectData<WidgetBase, qt_meta_tag_ZN10WidgetBaseE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WidgetBase::staticMetaObject = { {
    QMetaObject::SuperData::link<QGraphicsObjectWrapper::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10WidgetBaseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10WidgetBaseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10WidgetBaseE_t>.metaTypes,
    nullptr
} };

void WidgetBase::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WidgetBase *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotMenuSelection((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *WidgetBase::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WidgetBase::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10WidgetBaseE_t>.strings))
        return static_cast<void*>(this);
    return QGraphicsObjectWrapper::qt_metacast(_clname);
}

int WidgetBase::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsObjectWrapper::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
